<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Activar el plugin',
'affichage' => 'Visualizaci&oacute;n',
'aide_non_disponible' => 'Esta parte de la ayuda en l&iacute;nea a&uacute;n no est&aacute; disponible en este idioma.',
'auteur' => 'Autor:',
'avis_acces_interdit' => 'Acceso prohibido.',
'avis_article_modifie' => 'Atenci&oacute;n, @nom_auteur_modif@ trabaj&oacute; en este art&iacute;culo hace @date_diff@ minutos.',
'avis_aucun_resultat' => 'Ning&uacute;n resultado.',
'avis_chemin_invalide_1' => 'El camino escogido',
'avis_chemin_invalide_2' => 'no parece v&aacute;lido. Regresa a la p&aacute;gina precedente y comprueba las informaciones procuradas.',
'avis_connexion_echec_1' => 'Fall&oacute; la conexi&oacute;n con la base de datos',
'avis_connexion_echec_2' => 'Regresa a la p&aacute;gina precedente y verifica las informaciones procuradas.',
'avis_connexion_echec_3' => '<b>OjO:</b> En muchos servidores, es necesario <b>pedir</b> la activaci&oacute;n del acceso a la base de datos antes de poder usarla. Si no puedes conectarte, verifica que hiciste dicho tr&aacute;mite.',
'avis_connexion_ldap_echec_1' => 'La conexi&oacute;n al servidor LDAP ha fallado.',
'avis_connexion_ldap_echec_2' => 'Regresa a la p&aacute;gina anterior y comprueba las informaciones procuradas.',
'avis_connexion_ldap_echec_3' => 'Alternativamente, no utilices el soporte LDAP para importar usuarios y usuarias.',
'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b> Se aconseja seleccionar una palabra clave de este grupo.',
'avis_deplacement_rubrique' => '&iexcl;ATENCI&Oacute;N! Esta secci&oacute;n contiene @contient_breves@ breve@scb@. Si la desplazas, activa esta casilla de confirmaci&oacute;n.',
'avis_destinataire_obligatoire' => 'Debes indicar un destinatario antes de enviar este mensaje.',
'avis_doublon_mot_cle' => 'Ya existe una palabra con ese t&iacute;tulo. &iquest;Est&aacute;s seguro que quieres crear otra con el mismo?',
'avis_erreur_connexion_mysql' => 'Error de conexi&oacute;n SQL',
'avis_erreur_version_archive' => '<b>&iexcl;OjO! El archivo @archive@ corresponde a
 otra versi&oacute;n de SPIP, diferente a la instalada.</b> Si sigues podr&aacute;s encontrar grandes
 dificultades: riesgo de destrucci&oacute;n de tu base de
 datos, disfuncionamientos varios del sitio, etc. No
 valides esta importaci&oacute;n.<p>Para mayor informaci&oacute;n, ver
 <a href="@spipnet@">la documentaci&oacute;n de SPIP</a></p>.',
'avis_espace_interdit' => '<b>Espacio prohibido</b><div>SPIP ya est&aacute; instalado.</div>',
'avis_lecture_noms_bases_1' => 'El programa de instalaci&oacute;n no logr&oacute; leer los nombres de las bases de datos instaladas.',
'avis_lecture_noms_bases_2' => 'Dos posibilidades: o no hay ninguna base disponible o la funci&oacute;n de listado de las bases fue desactivada por razones de seguridad (caso frecuente en muchos hospedajes).',
'avis_lecture_noms_bases_3' => 'En el segundo caso, es probable que una base que tenga como nombre tu login sea utilizable:',
'avis_non_acces_message' => 'No tienes acceso a este mensaje.',
'avis_non_acces_page' => 'No tienes acceso a esta p&aacute;gina.',
'avis_operation_echec' => 'La operaci&oacute;n ha fallado.',
'avis_operation_impossible' => 'Operaci&oacute;n imposible',
'avis_probleme_archive' => 'Problema de lectura del archivo @archive@',
'avis_site_introuvable' => 'No se encuentra el sitio',
'avis_site_syndique_probleme' => 'ATENCI&Oacute;N: la sindicaci&oacute;n de ese sitio encontr&oacute; un problema; por lo cual se interrumpi&oacute; el sistema temporalmente. Verifica la direcci&oacute;n del archivo de sindicaci&oacute;n de este sitio (<b>@url_syndic@</b>), e intenta una nueva recuperaci&oacute;n de la informaci&oacute;n.',
'avis_sites_probleme_syndication' => 'Estos sitios tienen un problema de sindicaci&oacute;n',
'avis_sites_syndiques_probleme' => 'Estos sitios sindicados tienen problemas',
'avis_suppression_base' => '&iexcl;ATENCI&Oacute;N, la supresi&oacute;n de datos es irreversible!',
'avis_version_mysql' => 'Tu servidor SQL (@version_mysql@) no permite la auto-reparaci&oacute;n de tablas en la base.',

// B
'bouton_acces_ldap' => 'A&ntilde;adir un acceso LDAP',
'bouton_ajouter' => 'A&ntilde;adir',
'bouton_ajouter_participant' => 'A&Ntilde;ADIR UN PARTICIPANTE:',
'bouton_annonce' => 'ANUNCIO',
'bouton_annuler' => 'Anular',
'bouton_checkbox_envoi_message' => 'posibilidad de enviar un mensaje',
'bouton_checkbox_indiquer_site' => 'indicar obligatoriamente un sitio Web',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los administradores y administradoras del sitio',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Redactoras y redactores',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes del sitio p&uacute;bico, cuando se expresan en los foros p&uacute;blicos.',
'bouton_checkbox_signature_unique_email' => 'una sola firma por correo electr&oacute;nico',
'bouton_checkbox_signature_unique_site' => 'una sola firma por sitio Web',
'bouton_demande_publication' => 'Pedir la publicaci&oacute;n de este art&iacute;culo',
'bouton_desactive_tout' => 'Desactivar todo',
'bouton_desinstaller' => 'Desinstalar',
'bouton_effacer_index' => 'Borrar los &iacute;ndices',
'bouton_effacer_statistiques' => 'Borrar las estad&iacute;sticas',
'bouton_effacer_tout' => '&iexcl;Borrar TODO!',
'bouton_envoi_message_02' => 'ENVIAR UN MENSAJE',
'bouton_envoyer_message' => 'Mensaje definitivo: enviar',
'bouton_forum_petition' => 'FORO &amp; FIRMAS',
'bouton_modifier' => 'Modificar',
'bouton_pense_bete' => 'RECORDATORIO PERSONAL',
'bouton_radio_activer_messagerie' => 'Activar la mensajer&iacute;a interna',
'bouton_radio_activer_messagerie_interne' => 'Activar la mensajer&iacute;a interna',
'bouton_radio_activer_petition' => 'Activar la petici&oacute;n',
'bouton_radio_afficher' => 'Mostrar',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparecer en la lista de redactores y redactoras conectados',
'bouton_radio_articles_futurs' => 'a los art&iacute;culos futuros solamente (no modifica la base de datos).',
'bouton_radio_articles_tous' => 'a todos los art&iacute;culos sin excepci&oacute;n.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos los art&iacute;culos, salvo aquellos cuyo foro est&aacute; desactivado.',
'bouton_radio_desactiver_messagerie' => 'Desactivar le mensajer&iacute;a',
'bouton_radio_enregistrement_obligatoire' => 'Inscripci&oacute;n obligatoria (es necesario inscribirse dando su correo electr&oacute;nico antes de poder participar en el foro).',
'bouton_radio_envoi_annonces_adresse' => 'Enviar los anuncios a la direcci&oacute;n:',
'bouton_radio_envoi_liste_nouveautes' => 'Enviar la lista de novedades',
'bouton_radio_moderation_priori' => 'Moderado a priori (las contribuciones no aparecen hasta ser validadas por una persona con derechos de administraci&oacute;n en el sitio).',
'bouton_radio_modere_abonnement' => 's&oacute;lo para inscritos',
'bouton_radio_modere_posteriori' => 'moderado a posteriori',
'bouton_radio_modere_priori' => 'moderado a priori',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'No aparecer en la lista de redactores y redactoras',
'bouton_radio_non_envoi_annonces_editoriales' => 'No enviar anuncios editoriales',
'bouton_radio_non_syndication' => 'Ninguna sindicaci&oacute;n',
'bouton_radio_pas_petition' => 'Sin petici&oacute;n',
'bouton_radio_petition_activee' => 'Petici&oacute;n activada',
'bouton_radio_publication_immediate' => 'Publicaci&oacute;n inmediata de los mensajes (las contribuciones aparecen en cuanto enviadas, pueden suprimirse posteriormente desde la administraci&oacute;n).',
'bouton_radio_sauvegarde_compressee' => 'respaldo comprimido en @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'respaldo no comprimido en @fichier@',
'bouton_radio_supprimer_petition' => 'Suprimir la petici&oacute;n',
'bouton_radio_syndication' => 'Sindicaci&oacute;n',
'bouton_redirection' => 'Redirecci&oacute;n',
'bouton_relancer_installation' => 'Relanzar la instalaci&oacute;n',
'bouton_restaurer_base' => 'Restaurar la base',
'bouton_suivant' => 'Siguiente',
'bouton_tenter_recuperation' => 'Intentar reparar',
'bouton_test_proxy' => 'Probar el proxy',
'bouton_vider_cache' => 'Vaciar la cach&eacute;',
'bouton_voir_message' => 'Ver el mensaje antes de enviarlo',

// C
'cache_mode_compresse' => 'Los archivos de cach&eacute; se almacenan en modo comprimido.',
'cache_mode_non_compresse' => 'Los archivos de cach&eacute; se almacenan en modo no comprimido.',
'cache_modifiable_webmestre' => 'Este par&aacute;metro es modificable por la webmistress del sitio.',
'calendrier_synchro' => 'Si utilizas un software de agenda compatible <b>iCal</b>, puedes sincronizarlo con la actualidad editorial de este sitio.',
'config_activer_champs' => 'Activar los campos siguientes',
'config_choix_base_sup' => 'indicar una base de datos de este servidor',
'config_erreur_base_sup' => 'SPIP no tiene acceso a la lista de bases accesibles',
'config_info_base_sup' => 'Si dispones de otras bases de datos a consultar mediante SPIP, con su servidor SQL o con otro, el formulario siguiente permite declararlas. Si dejas vac&iacute;os ciertos campos, se usar&aacute;n los identificadores de la conexi&oacute;n a la base principal.',
'config_info_base_sup_disponibles' => 'Bases de datos suplementarias consultables:',
'config_info_enregistree' => 'La nueva configuraci&oacute;n fue guardada',
'config_info_logos' => 'Cada elemento del sitio puede tener un logo, as&iacute; como un &laquo;&nbsp;logo de paso del rat&oacute;n&nbsp;&raquo;',
'config_info_logos_utiliser' => 'Utilizar los logos',
'config_info_logos_utiliser_non' => 'No utilizar los logos',
'config_info_logos_utiliser_survol' => 'Utilizar los logos de paso del rat&oacute;n',
'config_info_logos_utiliser_survol_non' => 'No utilizar los logos de paso del rat&oacute;n',
'config_info_redirection' => 'Activando esta opci&oacute;n, se podr&aacute;n crear art&iacute;culos virtuales, que son simples referencias de art&iacute;culos publicados en otros sitios o fuera de SPIP.',
'config_redirection' => 'Art&iacute;culos virtuales',
'config_titre_base_sup' => 'Declaraci&oacute;n de una base suplementaria',
'config_titre_base_sup_choix' => 'Elige una base suplementaria',
'connexion_ldap' => 'Conexi&oacute;n:',
'copier_en_local' => 'Copiar en local',

// D
'date_mot_heures' => 'horas',
'diff_para_ajoute' => 'P&aacute;rrafo a&ntilde;adido',
'diff_para_deplace' => 'P&aacute;rrafo desplazado',
'diff_para_supprime' => 'P&aacute;rrafo suprimido',
'diff_texte_ajoute' => 'Texto a&ntilde;adido',
'diff_texte_deplace' => 'Texto desplazado',
'diff_texte_supprime' => 'Texto suprimido',
'double_clic_inserer_doc' => 'Haga doble clic para insertar este atajo en el texto',

// E
'email' => 'correo electr&oacute;nico',
'email_2' => 'correo electr&oacute;nico:',
'en_savoir_plus' => 'M&aacute;s informaci&oacute;n',
'entree_adresse_annuaire' => 'Direcci&oacute;n del anuario',
'entree_adresse_email' => 'Tu correo electr&oacute;nico',
'entree_adresse_fichier_syndication' => 'Direcci&oacute;n del archivo de sindicaci&oacute;n:',
'entree_adresse_site' => '<b>Direcci&oacute;n del sitio</b> [Obligatorio]',
'entree_base_donnee_1' => 'Direcci&oacute;n de la base de datos',
'entree_base_donnee_2' => '(A menudo esta direcci&oacute;n corresponde a la de tu sitio, a veces corresponde a la menci&oacute;n &laquo;localhost&raquo; y, en ocasiones, se deja totalmente vac&iacute;a.)',
'entree_biographie' => 'Una corta biograf&iacute;a, en pocas palabras...',
'entree_breve_publiee' => '&iquest;Publicamos &eacute;sta breve?',
'entree_chemin_acces' => '<b>Entrar</b> el camino de acceso:',
'entree_cle_pgp' => 'Tu clave PGP',
'entree_contenu_rubrique' => '(Contenido de la secci&oacute;n, en pocas palabras)',
'entree_description_site' => 'Descripci&oacute;n del sitio',
'entree_identifiants_connexion' => 'Tus identificadores de conexi&oacute;n...',
'entree_informations_connexion_ldap' => 'Escriba en este formulario los datos de conexi&amp;oacute;n a tu directorio LDAP. Tales informaciones te ser&aacute;n transmitidas por el administrador del sistema o de la red.',
'entree_infos_perso' => '&iquest;Qui&eacute;n eres?',
'entree_interieur_rubrique' => 'En el interior de la secci&oacute;n...',
'entree_liens_sites' => '<b>Enlace hipertexto </b>(referencia, sitio para visitar, ...)',
'entree_login' => 'Tu login',
'entree_login_connexion_1' => 'Tu identificador de conexi&oacute;n',
'entree_login_connexion_2' => '(A veces corresponde al login de conexi&oacute;n y a veces se deja vac&iacute;o)',
'entree_login_ldap' => 'Login LDAP inicial',
'entree_mot_passe' => 'Tu contrase&ntilde;a',
'entree_mot_passe_1' => 'Tu contrase&ntilde;a de conexi&oacute;n',
'entree_mot_passe_2' => '(A veces corresponde a tu contrase&ntilde;a FTP y a veces se deja en blanco)',
'entree_nom_fichier' => 'Introducir el nombre del archivo @texte_compresse@:',
'entree_nom_pseudo' => 'Tu nombre o seud&oacute;nimo',
'entree_nom_pseudo_1' => '(Tu nombre o seud&oacute;nimo)',
'entree_nom_site' => 'El nombre de tu sitio',
'entree_nouveau_passe' => 'Nueva contrase&ntilde;a',
'entree_passe_ldap' => 'Tu contrase&ntilde;a',
'entree_port_annuaire' => 'El n&uacute;mero de puerto del anuario',
'entree_signature' => 'Firma',
'entree_texte_breve' => 'Texto de la breve',
'entree_titre_obligatoire' => '<b>T&iacute;tulo</b> [Obligatorio]<br />',
'entree_url' => 'La direcci&oacute;n (URL) de tu sitio',
'erreur_plugin_desinstalation_echouee' => 'La desinstalaci&oacute;n del plugin fracas&oacute;.No obstante, puedes desactivarlo.',
'erreur_plugin_fichier_absent' => 'Archivo inexistente ',
'erreur_plugin_fichier_def_absent' => 'Archivo de definici&oacute;n inexistente',
'erreur_plugin_nom_fonction_interdit' => 'Nombre de funci&oacute;n prohibido',
'erreur_plugin_nom_manquant' => 'Falta el nombre del plugin',
'erreur_plugin_prefix_manquant' => 'Espacio de nombres del plugin no definido',
'erreur_plugin_tag_plugin_absent' => 'Falta el &lt;plugin&gt; en el archivo de  definici&oacute;n',
'erreur_plugin_version_manquant' => 'Falta la versi&oacute;n del plugin',

// F
'forum_info_original' => 'original',

// H
'htaccess_a_simuler' => 'Advertencia: la configuraci&oacute;n de tu servidor HTTP no toma en ceunta los archivos @htaccess@. Para poder asegurar una buena seguridad, debes modificar la configuraci&oacute;n correspondiente, o si no que las constantes @constantes@ (que se pueden definir en el archivo mes_options.php) tomen valores de carpetas fuera de @document_root@.',
'htaccess_inoperant' => 'htaccess inoperante',

// I
'ical_info1' => 'En esta p&aacute;gina se presentan diferentes maneras de quedar en contacto con la vida del sitio.',
'ical_info2' => 'Para mayor informaci&oacute;n sobre todas estas t&eacute;cnicas, no dudes en consultar <a href="@spipnet@">la documentaci&oacute;n de SPIP</a>.',
'ical_info_calendrier' => 'Tienes dos calendarios a tu disposici&oacute;n. El primero es un plano del sitio que anuncia todos los art&iacute;culos publicados. El segundo contiene los anuncios editoriales y tus &uacute;ltimos mensajes privados: s&oacute;lo t&uacute; lo v&eacute;s gracias a una clave personal, que podr&aacute;s modificar en cualquier momento cambiando tu contrase&ntilde;a.',
'ical_lien_rss_breves' => 'Sindicaci&oacute;n de breves del sitio',
'ical_methode_http' => 'Descargar',
'ical_methode_webcal' => 'Sincronizaci&oacute;n (webcal://)',
'ical_texte_js' => 'Una l&iacute;nea de javascript te permite mostrar muy simplemente, en cualquier sitio que te pertenece, los art&iacute;culos recientes publicados en este sitio.',
'ical_texte_prive' => 'Este calendario, de uso estrictamente personal, te informa de la actividad editorial privada de este sitio (tareas y citas personales, art&iacute;culos y breves propuestos...)',
'ical_texte_public' => 'Este calendario permite seguir la actividad p&uacute;blica del sitio (art&iacute;culos y breves publicados).',
'ical_texte_rss' => 'Puedes sindicar las novedades de este sitio con cualquier lector de archivos al formato XML/RSS (Rich Site Summary). Igualmente, SPIP puede leer las novedades publicadas en otros sitios que utilizan un formato de intercambio compatible (sitios sindicados). ',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Lista de correo',
'ical_titre_rss' => 'Archivos de sindicaci&oacute;n',
'icone_activer_cookie' => 'Activar la "cookie" de correspondencia',
'icone_admin_plugin' => 'Gesti&oacute;n de los plugins',
'icone_afficher_auteurs' => 'Mostrar los autores y autoras',
'icone_afficher_visiteurs' => 'Mostrar los y las visitantes',
'icone_arret_discussion' => 'No participar m&aacute;s en este di&aacute;logo',
'icone_calendrier' => 'Calendario',
'icone_creation_groupe_mots' => 'Crear un nuevo grupo de palabras',
'icone_creation_mots_cles' => 'Crear una nueva palabra clave',
'icone_creer_auteur' => 'Crear un nuevo autor o autora y asociarla a este art&iacute;culo',
'icone_creer_mot_cle' => 'Crear una nueva palabra clave y asociarla a este art&iacute;culo',
'icone_creer_mot_cle_breve' => 'Crear una nueva palabra clave y aplicarla a esta breve',
'icone_creer_mot_cle_rubrique' => 'Crear una nueva palabra clave y aplicarla a esta secci&oacute;n',
'icone_creer_mot_cle_site' => 'Crear una nueva palabra clave y aplicarla a este sitio',
'icone_creer_rubrique_2' => 'Crear una nueva secci&oacute;n',
'icone_ecrire_nouvel_article' => 'Las breves de esta secci&oacute;n',
'icone_envoyer_message' => 'Enviar el mensaje',
'icone_evolution_visites' => 'Evoluci&oacute;n de las visitas<br />@visites@ visitas',
'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
'icone_modifier_article' => 'Modificar este art&iacute;culo',
'icone_modifier_breve' => 'Modificar esta breve',
'icone_modifier_message' => 'Modificar el mensaje',
'icone_modifier_mot' => 'Modificar esta palabra clave',
'icone_modifier_rubrique' => 'Modificar esta secci&oacute;n',
'icone_modifier_site' => 'Modificar este sitio',
'icone_poster_message' => 'Enviar un mensaje',
'icone_publier_breve' => 'Publicar esta breve',
'icone_referencer_nouveau_site' => 'Referenciar un nuevo sitio',
'icone_refuser_breve' => 'Rechazar esta breve',
'icone_relancer_signataire' => 'Recordar al firmante',
'icone_retour' => 'Volver',
'icone_retour_article' => 'Volver al art&iacute;culo',
'icone_suivi_forum' => 'Actualidad del foro p&uacute;blico: @nb_forums@ contribuci&oacute;n(es)',
'icone_supprimer_cookie' => 'Suprimir la "cookie" de correspondencia',
'icone_supprimer_groupe_mots' => 'Suprimir este grupo',
'icone_supprimer_rubrique' => 'Suprimir esta secci&oacute;n',
'icone_supprimer_signature' => 'Suprimir esta firma',
'icone_valider_signature' => 'Validar esta firma',
'icone_voir_sites_references' => 'Ver los sitios referenciados',
'icone_voir_tous_mots_cles' => 'Ver todas las palabras clave',
'image_administrer_rubrique' => 'Puedes administrar esta secci&oacute;n',
'info_1_article' => '1 art&iacute;culo',
'info_1_breve' => '1 breve',
'info_1_site' => '1 sitio',
'info_activer_cookie' => 'Puedes activar una <b>"cookie" de correspondencia</b>, que te permite actualizar p&aacute;ginas y pasar f&aacute;cilmente de la parte p&uacute;blica a la redacci&oacute;n.',
'info_activer_forum_public' => '<i>Para activar los foros p&uacute;blicos, seleccionar un modo de moderaci&oacute;n por omisi&oacute;n:</i>',
'info_admin_gere_rubriques' => 'Esta persona administra las secciones siguientes :',
'info_admin_gere_toutes_rubriques' => 'Este administrador gestiona <b>todas las secciones</b>.',
'info_admin_statuer_webmestre' => 'Dar a este/a administrador/a derechos de webmestre. ',
'info_admin_webmestre' => 'Este/a administrador/a es <b>webmestre</b>',
'info_administrateur' => 'Administrador o administradora',
'info_administrateur_1' => 'Administrador',
'info_administrateur_2' => 'del sitio (<i>a utilizar con precauci&oacute;n</i>)',
'info_administrateur_site_01' => 'Si tienes derechos de administraci&oacute;n, se ruega',
'info_administrateur_site_02' => 'presiona y visita este enlace',
'info_administrateurs' => 'Administradores',
'info_administrer_rubrique' => 'Puedes administrar esta secci&oacute;n',
'info_adresse' => 'a la direcci&oacute;n:',
'info_adresse_email' => 'Direcci&oacute;n de correo electr&oacute;nico:',
'info_adresse_url' => 'Direcci&oacute;n (URL) del sitio p&uacute;blico',
'info_afficher_visites' => 'Mostrar las visitas para:',
'info_affichier_visites_articles_plus_visites' => 'Mostrar las visitas de <b>los art&iacute;culos m&aacute;s visitados desde el inicio:</b>',
'info_aide_en_ligne' => 'Ayuda en l&iacute;nea de SPIP',
'info_ajout_image' => 'Cuando se a&ntilde;aden im&aacute;genes en tanto que documentos SPIP puede crear autom&aacute;ticamente iconos de estas im&aacute;genes insertadas (miniaturas). Resulta &uacute;til, por ejemplo, para crear una galer&iacute;a o portafolio.',
'info_ajout_participant' => 'El participante siguiente ha sido a&ntilde;adido:',
'info_ajouter_rubrique' => 'A&ntilde;adir otra secci&oacute;n para administrar',
'info_annonce_nouveautes' => 'Anunciar novedades',
'info_anterieur' => 'anterior',
'info_appliquer_choix_moderation' => 'Aplicar este tipo de moderaci&oacute;n',
'info_article' => 'art&iacute;culo',
'info_article_2' => 'art&iacute;culos',
'info_article_a_paraitre' => 'Los art&iacute;culos con fecha posterior a ser publicados',
'info_articles_02' => 'art&iacute;culos',
'info_articles_2' => 'Art&iacute;culos',
'info_articles_auteur' => 'Los art&iacute;culos de esta autora o autor',
'info_articles_lies_mot' => 'Los art&iacute;culos ligados a esta palabra clave',
'info_articles_trouves' => 'Art&iacute;culos localizados',
'info_articles_trouves_dans_texte' => 'Art&iacute;culos encontrados (en el texto)',
'info_attente_validation' => 'Tus art&iacute;culos en espera de validaci&oacute;n',
'info_aujourdhui' => 'hoy:',
'info_auteur_message' => 'AUTOR O AUTORA DEL MENSAJE:',
'info_auteurs' => 'Autores y autoras',
'info_auteurs_par_tri' => 'Autores@partri@',
'info_auteurs_trouves' => 'Autores y autoras encontrados',
'info_authentification_externe' => 'Autentificaci&oacute;n externa',
'info_avertissement' => 'Advertencia',
'info_barre_outils' => '&iquest;con su barra de herramientas?',
'info_base_installee' => 'La estructura de tu base de datos ha sido instalada',
'info_base_restauration' => 'La base est&aacute; siendo restaurada',
'info_bloquer' => 'bloquear',
'info_breves' => 'Puedes utilizar el sistema de breves',
'info_breves_03' => 'breves',
'info_breves_liees_mot' => 'Las breves ligadas a esta palabra clave',
'info_breves_touvees' => 'Breves localizadas',
'info_breves_touvees_dans_texte' => 'Breves localizadas (en el texto)',
'info_changer_nom_groupe' => 'Cambiar el nombre de este grupo',
'info_chapeau' => 'Ep&iacute;grafe',
'info_chapeau_2' => 'Ep&iacute;grafe:',
'info_chemin_acces_1' => 'Opciones: <b>camino de acceso en el directorio</b>',
'info_chemin_acces_2' => 'Se debe configurar el camino de acceso a las informaciones en el anuario. Esta informaci&oacute;n es indispensable para leer los perfiles de personas almacenados en el anuario.',
'info_chemin_acces_annuaire' => 'Opciones: <b>Camino de acceso en el directorio</b>',
'info_choix_base' => 'Tercera etapa:',
'info_classement_1' => '<sup>o</sup> sobre @liste@',
'info_classement_2' => '<sup>o</sup> sobre @liste@',
'info_code_acces' => '&iexcl;No olvides tus c&oacute;digos de acceso!',
'info_comment_lire_tableau' => 'Como leer este cuadro',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Se recomienda verificar previamente si el proveedor comprime sistem&aacute;ticamente los scripts php&nbsp;; para ello, se puede, por ejemplo, utilizar el servicio siguiente&nbsp;: @testgzip@',
'info_compresseur_texte' => 'Si tu servidor no comprime autom&aacute;ticamente las p&aacute;ginas html para enviarlas a los internautas, puedes intentar forzar la compresi&oacute;n para disminuir el tama&ntilde;o de las p&aacute;ginas enviadas. <b>Atenci&oacute;n:</b> esto puede ralentizar considerablemente ciertos servidores.',
'info_compresseur_titre' => 'Optimizaciones y compresi&oacute;n',
'info_config_forums_prive' => 'En el espacio privado del sitio, se pueden activar varios tipos de foros&nbsp;:',
'info_config_forums_prive_admin' => 'Un foro reservado a los administradores del sitio&nbsp;:',
'info_config_forums_prive_global' => 'Un foro global, abierto a todos los redactores&nbsp;:',
'info_config_forums_prive_objets' => 'Un foro para cada art&iacute;culo, breve, sitio referenciado, etc.&nbsp;:',
'info_config_suivi' => 'Si esta direcci&oacute;n corresponde a una lista de correo, puedes indicar aqu&iacute; abajo la direcci&oacute;n en la cual los participantes al sitio pueden inscribirse. Esta direcci&oacute;n puede ser una URL (por ejemplo la p&aacute;gina de inscripci&oacute;n a la lista por la web), o una direcci&oacute;n e-mail con un asunto espec&iacute;fico (por ejemplo: <tt>@direccion_abonar@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'Puedes suscribirte a la lista de correo de este sitio. Recibir&aacute;s por correo electr&oacute;nico los anuncios de art&iacute;culos y de bereves propuestas a la publicaci&oacute;n.',
'info_confirmer_passe' => 'Confirmar la nueva contrase&ntilde;a:',
'info_conflit_edition_avis_non_sauvegarde' => 'Atenci&oacute;n, los siguientes campos han sido modificados por oro lado. Tus modificaciones sobre estos campos no han sido por tanto registradas.',
'info_conflit_edition_differences' => 'Diferencias&nbsp;:',
'info_conflit_edition_version_enregistree' => 'La versi&oacute;n registrada&nbsp;:',
'info_conflit_edition_votre_version' => 'Su versi&oacute;n&nbsp;:',
'info_connexion_base' => 'Intento de conexi&oacute;n a la base',
'info_connexion_base_donnee' => 'Conexi&oacute;n a tu base de datos',
'info_connexion_ldap_ok' => 'Se logr&oacute; la conexi&oacute;n LDAP.</b><p> Puedes pasar a la etapa siguiente.</b>',
'info_connexion_mysql' => 'Tu conexi&oacute;n SQL',
'info_connexion_ok' => 'La conexi&oacute;n ha funcionado.',
'info_contact' => 'Contacto',
'info_contenu_articles' => 'Contenido de los art&iacute;culos',
'info_creation_mots_cles' => 'Crear y configurar las palabras clave del sitio',
'info_creation_paragraphe' => '(Para crear p&aacute;rrafos, deja l&iacute;neas vac&iacute;as.)',
'info_creation_rubrique' => 'Antes de poder escribir art&iacute;culos,<br /> debes crear al menos una secci&oacute;n.<br />',
'info_creation_tables' => 'Creaci&oacute;n de las tablas de la base',
'info_creer_base' => '<b>Crear</b> una nueva base de datos:',
'info_dans_groupe' => 'En el grupo',
'info_dans_rubrique' => 'En la secci&oacute;n...',
'info_date_publication_anterieure' => 'Fecha de redacci&oacute;n anterior:',
'info_date_referencement' => 'FECHA DE SINDICACI&Oacute;N DE ESTE SITIO&nbsp;:',
'info_delet_mots_cles' => 'Pediste la supresi&oacute;n de la palabra clave
<b>@titre_mot@</b> (@type_mot@). Como esta palabra clave est&aacute; relacionada a 
<b>@texte_lie@</b>, debes confirmar esta decisi&oacute;n:',
'info_derniere_etape' => '&iexcl;Ya terminamos!',
'info_derniere_syndication' => 'La &uacute;ltima sindicaci&oacute;n de este sitio fue realizada el',
'info_derniers_articles_publies' => 'Tus &uacute;ltimos art&iacute;culos publicados',
'info_desactiver_forum_public' => 'Desactivar los foros p&uacute;blicos. Podr&aacute;n ser activados puntualmente para los art&iacute;culos, pero no para las breves o las secciones.',
'info_desactiver_messagerie_personnelle' => 'Puedes activar o desactivar tu mensajer&iacute;a personal en este sitio.',
'info_descriptif' => 'Descripci&oacute;n:',
'info_desinstaller_plugin' => 'suprime los datos y desactiva el plugin',
'info_discussion_cours' => 'Debates en curso',
'info_ecrire_article' => 'Antes de escribir art&iacute;culos, debes crear una secci&oacute;n.',
'info_email_envoi' => 'Direcci&oacute;n de correo de env&iacute;o (opcional)',
'info_email_envoi_txt' => 'Indica aqui la direcci&oacute;n que se utiliza como expeditor al mandar los correos electr&oacute;nicos (por omisi&oacute;n, se utiliza la direcci&oacute;n del destinatario como direcci&oacute;n de env&iacute;o)&nbsp;:',
'info_email_webmestre' => 'Direcci&oacute;n de correo electr&oacute;nico del/la webmaster (opcional)',
'info_entrer_code_alphabet' => 'Introduce el c&oacute;digo del alfabeto a utilizar',
'info_envoi_email_automatique' => 'Env&iacute;o autom&aacute;tico de correos electr&oacute;nicos',
'info_envoi_forum' => 'Seguimiento de los foros',
'info_envoyer_maintenant' => 'Enviar ahora',
'info_erreur_restauration' => 'Error de restauraci&oacute;n. Archivo inexistente.',
'info_etape_suivante' => 'Pasar a la siguiente etapa ',
'info_etape_suivante_1' => 'Puedes pasar a la siguiente etapa ',
'info_etape_suivante_2' => 'Puedes pasar a la etapa siguiente',
'info_exportation_base' => 'exportaci&oacute;n de la base hacia @archive@',
'info_facilite_suivi_activite' => 'Para facilitar el seguimiento de la actividad editorial, SPIP puede enviar por correo electr&oacute;nico, por ejemplo a un lista de redactores y redactoras, anuncios de solicitudes de publicaci&oacute;n y de validaci&oacute;n de art&iacute;culos.',
'info_fichiers_authent' => 'Archivos de autentificaci&oacute;n &laquo;.htpasswd&raquo;',
'info_fonctionnement_forum' => 'Funcionamiento del foro:',
'info_forum_administrateur' => 'Foro del grupo de administraci&oacute;n ',
'info_forum_interne' => 'foro interno',
'info_forum_ouvert' => 'En el espacio privado del sitio hay un foro abierto a todas las personas inscritas. A continuaci&oacute;n, puedes activar un foro suplementario reservado a los administradores y administradoras.',
'info_forum_statistiques' => 'Estad&iacute;sticas de las visitas',
'info_forums_abo_invites' => 'Tu sitio tiene foros para abonados; en el sitio p&uacute;blico se invita a los visitantes a que se registren.',
'info_gauche_admin_effacer' => '<b>A esta p&aacute;gina s&oacute;lo pueden acceder  los/las responsables del sitio.</b><p> Da acceso a las distintas funciones de mantenimiento t&eacute;cnico. Algunas de ellas comprenden un proceso de autenticaci&oacute;n, que requiere un acceso FTP al sitio web.</p>',
'info_gauche_admin_tech' => '<b>S&oacute;lo los y las responsables del sitio acceden a esta p&aacute;gina.</b><p> Da acceso a las distintas funciones de mantenimiento t&eacute;cnico. Algunas de ellas requieren un proceso de autentificaci&oacute;n para el cual es necesario tener acceso por FTP al sitio web.</p>',
'info_gauche_admin_vider' => '<b>Esta p&aacute;gina s&oacute;lo es accesible para los/las responsables del sitio.</b><p> Da acceso a las distintas funciones de mantenimiento t&eacute;cnico. Algunas de ellas dan lugar a un proceso de autentificaci&oacute;n para el cual es necesario tener acceso por FTP al sitio web.</p>',
'info_gauche_auteurs' => 'Aqu&iacute; figuran todos los autores y autoras del sitio.
 Su estado se indica con el color de su icono (administrador/a = verde; redactor/a = amarillo).',
'info_gauche_auteurs_exterieurs' => 'Los autores y autoras exteriores, sin acceso al sitio, est&aacute;n indicados con un icono azul; los que est&aacute;n borrados con una papelera.',
'info_gauche_messagerie' => 'La mensajer&iacute;a permite comunicarse, crear recordatorios para traer a la memoria algo o publicar anuncios (en el caso de pertenecer al grupo de administraci&oacute;n).',
'info_gauche_numero_auteur' => 'AUTOR O AUTORA N&Uacute;MERO',
'info_gauche_numero_breve' => 'Breve',
'info_gauche_statistiques_referers' => 'Esta p&aacute;gina presenta la lista de los <i>referers</i>, es decir de los sitios que contienen enlaces que llevan a tu propio sitio, s&oacute;lo para ayer y hoy; esta lista se pone a cero cada 24 horas.',
'info_gauche_suivi_forum' => 'La p&aacute;gina de <i>seguimiento de los foros</i> es una herramienta de gesti&oacute;n de tu sitio (y no un espacio de di&aacute;logo o de redacci&oacute;n). Muestra todas las contribuciones del foro p&uacute;blico de este art&iacute;culo y te permite administrarlas.',
'info_gauche_suivi_forum_2' => 'La p&aacute;gina de <i>seguimiento de los foros</i> es una herramienta de gesti&oacute;n de tu sitio (y no un espacio de di&aacute;logo o de redacci&oacute;n). Muestra todas las contribuciones del foro p&uacute;blico de este art&iacute;culo y te permite gestionar administrarlas.',
'info_gauche_visiteurs_enregistres' => 'Aqu&iacute; se encuentran las personas registradas en el espacio p&uacute;blico del sitio (foros con suscripci&oacute;n).',
'info_generation_miniatures_images' => 'Generaci&oacute;n de las miniaturas de im&aacute;genes',
'info_gerer_trad' => 'Manejar los enlaces de traducci&oacute;n?',
'info_groupe_important' => 'Grupo importante',
'info_hebergeur_desactiver_envoi_email' => 'Algunos servidores no permiten el env&iacute;o autom&aacute;tico de correos electr&oacute;nicos. En esos casos, las siguientes funciones de SPIP no dar&aacute;n ning&uacute;n resultado.',
'info_hier' => 'ayer:',
'info_historique' => 'Revisiones&nbsp;:',
'info_historique_activer' => 'Activar el seguimiento de revisiones',
'info_historique_affiche' => 'Mostrar esta versi&oacute;n',
'info_historique_comparaison' => 'comparaci&oacute;n',
'info_historique_desactiver' => 'Desactivar el seguimiento de revisiones',
'info_historique_lien' => 'Mostrar el historial de modificaciones',
'info_historique_texte' => 'El seguimiento de revisiones permite conservar un historial de todas las modificaciones hechas en el contenido de un art&iacute;culo, y mostrar las diferencias entre las sucesivas versiones.',
'info_historique_titre' => 'Seguimiento de revisiones',
'info_identification_publique' => 'Tu identidad p&uacute;blica...',
'info_image_process' => 'Por favor selecciona el mejor m&eacute;todo de fabricaci&oacute;n de vi&ntilde;etas pinchando en la im&aacute;gen correspondiente. ',
'info_image_process2' => '<b>N.B.</b> <i>Si no aparece ninguna imagen, se debe a que el servidor que alberga su sitio web no est&aacute; configurado para usar estas funciones. Si necesita utilizarlas, contacte con el responsable t&eacute;cnico y solicite las extensiones &laquo;GD&raquo; o &laquo;Imagick&raquo;.</i>',
'info_images_auto' => 'Im&aacute;genes calculadas autom&aacute;ticamente',
'info_informations_personnelles' => 'Informaciones personales',
'info_inscription_automatique' => 'Inscripcci&oacute;n autom&aacute;tica de nuevas personas',
'info_jeu_caractere' => 'Juego de caracteres del sitio',
'info_jours' => 'd&iacute;as',
'info_laisser_champs_vides' => 'dejar estos campos vac&iacute;os)',
'info_langues' => 'Idiomas del sitio',
'info_ldap_ok' => 'La autentificaci&oacute;n LDAP est&aacute; instalada.',
'info_lien_hypertexte' => 'Enlace hipertexto:',
'info_liens_syndiques_1' => 'enlaces sindicados',
'info_liens_syndiques_2' => 'est&aacute;n en espera de validaci&oacute;n.',
'info_liens_syndiques_3' => 'foros',
'info_liens_syndiques_4' => 'est&aacute;n',
'info_liens_syndiques_5' => 'foro',
'info_liens_syndiques_6' => 'est&aacute;',
'info_liens_syndiques_7' => 'en espera de validaci&oacute;n',
'info_liste_redacteurs_connectes' => 'Lista de redactores y redactoras conectadas',
'info_login_existant' => 'Ese login ya existe',
'info_login_trop_court' => 'Login muy corto',
'info_logos' => 'Los logos',
'info_maximum' => 'm&aacute;ximo:',
'info_meme_rubrique' => 'En la misma secci&oacute;n',
'info_message' => 'Mensaje del',
'info_message_efface' => 'Mensaje borrado',
'info_message_en_redaction' => 'Tus mensajes en curso de redacci&oacute;n',
'info_message_technique' => 'Mensaje t&eacute;cnico',
'info_messagerie_interne' => 'Mensajer&iacute;a interna',
'info_mise_a_niveau_base' => 'actualizaci&oacute;n de tu base SQL',
'info_mise_a_niveau_base_2' => '{{&iexcl;ATENCI&Oacute;N!}} Has instalado una versi&oacute;n de los archivos SPIP {anterior} a la que se encontraba antes en este sitio: Corres el riesgo de perder la base de datos y que el sitio deje de funcionar.<br />{{Vuelve a instalar los archivos de SPIP.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamiento de los foros p&uacute;blicos',
'info_modifier_auteur' => 'Modificar el autor:',
'info_modifier_breve' => 'Modificar la breve',
'info_modifier_mot' => 'Modificar la palabra clave:',
'info_modifier_rubrique' => 'Modificar la secci&oacute;n',
'info_modifier_titre' => 'Modificar @titre@',
'info_mon_site_spip' => 'Mi sitio SPIP',
'info_mot_sans_groupe' => '(Palabras sin grupo...)',
'info_moteur_recherche' => 'Motor de b&uacute;squeda integrado',
'info_mots_cles' => 'Las palabras clave',
'info_mots_cles_association' => 'Las palabras clave de este grupo pueden ser asociadas a...',
'info_moyenne' => 'promedio:',
'info_multi_articles' => '&iquest;Activar el men&uacute; de idioma en los art&iacute;culos?',
'info_multi_cet_article' => 'Idioma de este art&iacute;culo:',
'info_multi_langues_choisies' => 'A continuaci&oacute;n selecciona los idiomas que quieres poner a disposici&oacute;n de los redactores de tu sitio.
Los idiomas que ya se utilizan en el sitio (al principio de la lista) no pueden ser desactivados.
',
'info_multi_rubriques' => '&iquest;Activar el men&uacute; de idioma en las secciones?',
'info_multi_secteurs' => '... s&oacute;lo para las secciones situadas en la ra&iacute;z?',
'info_nom' => 'Nombre',
'info_nom_destinataire' => 'Nombre del destinatario o destinataria',
'info_nom_site' => 'Nombre de tu sitio',
'info_nom_site_2' => '<b>Nombre del sitio</b> [Obligatorio]',
'info_nombre_articles' => '@nb_articles@ art&iacute;culos,',
'info_nombre_breves' => '@nb_breves@ breves,',
'info_nombre_partcipants' => 'Participan en el debate...',
'info_nombre_rubriques' => '@nb_rubriques@ secciones,',
'info_nombre_sites' => '@nb_sites@ sitios,',
'info_non_deplacer' => 'No desplazar...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP puede enviar regularmente la lista de las novedades del sitio (art&iacute;culos y breves).',
'info_non_envoi_liste_nouveautes' => 'No enviar la lista de novedades',
'info_non_modifiable' => 'no puede ser modificado',
'info_non_suppression_mot_cle' => 'No deseo suprimir esta palabra clave',
'info_notes' => 'Notas',
'info_nouveaux_message' => 'Nuevos mensajes',
'info_nouvel_article' => 'Nuevo art&iacute;culo',
'info_nouvelle_traduction' => 'Nueva traducci&oacute;n:',
'info_numero_article' => 'Art&iacute;culo:',
'info_obligatoire_02' => '[Obligatorio]',
'info_option_accepter_visiteurs' => 'Aceptar la inscripci&oacute;n de los visitantes del sitio p&uacute;blico',
'info_option_email' => 'Cuando se deposita una nueva contribuci&oacute;n en un foro asociado a un art&iacute;culo, se puede notificarlo por correo electr&oacute;nico a los autores y autoras del art&iacute;culo. &iquest;Deseas utilizar esta opci&oacute;n?',
'info_option_faire_suivre' => 'Enviar los mensajes de los foros a los autores y autoras de art&iacute;culos',
'info_option_ne_pas_accepter_visiteurs' => 'Rehusar la inscripci&oacute;n de visitantes',
'info_option_ne_pas_faire_suivre' => 'No enviar los mensajes de los foros',
'info_options_avancees' => 'Opciones avanzadas',
'info_ortho_activer' => 'Activar el corrector ortogr&aacute;fico',
'info_ortho_desactiver' => 'Desactivar el corrector ortogr&aacute;fico',
'info_ou' => 'o...',
'info_oui_suppression_mot_cle' => 'Deseo suprimir esta palabra clave',
'info_page_interdite' => 'P&aacute;gina no accesible',
'info_par_nom' => 'por nombre',
'info_par_nombre_article' => 'por n&uacute;mero de art&iacute;culos',
'info_par_statut' => 'por estatuto',
'info_par_tri' => '\'(por @tri@)\'',
'info_pas_de_forum' => 'sin foro',
'info_passe_trop_court' => 'Contrase&ntilde;a demasiado corta',
'info_passes_identiques' => 'Hay diferencias entre las dos contrase&ntilde;as',
'info_pense_bete_ancien' => 'Tus antiguos recordatorios',
'info_plus_cinq_car' => 'm&aacute;s de 5 caracteres',
'info_plus_cinq_car_2' => '(M&aacute;s de 5 caracteres)',
'info_plus_trois_car' => '(M&aacute;s de tres caracteres)',
'info_popularite' => 'Popularidad: @popularite@ Visitas: @visites@',
'info_popularite_2' => 'Popularidad del sitio:',
'info_popularite_3' => 'Popularidad: @popularite@  Visitas: @visites@',
'info_popularite_4' => 'Popularidad: @popularite@  Visitas: @visites@',
'info_post_scriptum' => 'Post Scr&iacute;ptum',
'info_post_scriptum_2' => 'Post Scr&iacute;ptum:',
'info_pour' => 'para',
'info_preview_admin' => 'S&oacute;lo los administradores pueden previsualizar el sitio',
'info_preview_comite' => 'Todos los redactores pueden previsualizar el sitio',
'info_preview_desactive' => 'La previsualizaci&oacute;n est&aacute; totalmente desactivada',
'info_preview_texte' => 'Es posible previsualizar el sitio como si todos los art&iacute;culos y las breves (que tengan al menos el estado &laquo;&nbsp;propuesto&nbsp;&raquo;) estuviesen publicados. Esta posibilidad debe estar disponible para &iquest;&nbsp;los administradores solamente, todos los redactores, o nadie&nbsp;?',
'info_principaux_correspondants' => 'Tus principales corresponsales',
'info_procedez_par_etape' => 'proceder etapa por etapa',
'info_procedure_maj_version' => 'Se debe ejecutar el proceso de actualizaci&oacute;n de la base de datos a esta nueva versi&oacute;n de SPIP.',
'info_proxy_ok' => 'Test del proxy logrado.',
'info_ps' => 'P.-S.',
'info_publier' => 'publicar',
'info_publies' => 'Tus art&iacute;culos publicados',
'info_question_accepter_visiteurs' => 'Si en los esqueletos de tu sitio est&aacute; previsto el registro de visitantes sin acceso al espacio privado, tendr&aacute;s que activar la opci&oacute;n siguiente:',
'info_question_activer_compactage_css' => '&iquest;Desea activar la compresi&oacute;n de las hojas de estilo (CSS)?',
'info_question_activer_compactage_js' => '&iquest;Desea activar la compresi&oacute;n de los scripts (javascript) ?',
'info_question_activer_compresseur' => '&iquest;Desea activar la compresi&oacute;n del flujo HTTP ?',
'info_question_gerer_statistiques' => '&iquest;Deseas que tu sitio gestione las estad&iacute;sticas de las visitas?',
'info_question_inscription_nouveaux_redacteurs' => '&iquest;Se aceptan inscripciones de nuevas redactoras y redactores a partir del sitio p&uacute;blico? Si se acepta, las personas que visitan el sitio podr&aacute;n inscribirse desde un formulario automatizado y acceder&aacute;n entonces al espacio privado para proponer sus propios art&iacute;culos. <blockquote><i>Durante la fase de inscripci&oacute;n, reciben un correo electr&oacute;nico autom&aacute;tico que les indica sus c&oacute;digos de acceso al sitio privado. Ciertos proveedores de hospedaje desactivan el env&iacute;o de correos electr&oacute;nicos desde sus servidores: en tal caso, se hace imposible la inscripci&oacute;n autom&aacute;tica. ',
'info_question_mots_cles' => '&iquest;Deseas utilizar las palabras clave en tu sitio?',
'info_question_proposer_site' => '&iquest;Qui&eacute;n puede proponer los sitios referenciados?',
'info_question_utilisation_moteur_recherche' => '&iquest;Deseas utilizar el motor de b&uacute;squeda integrado de SPIP? (desactivarlo agiliza el sitio)',
'info_question_vignettes_referer' => 'Cuando consultes las estad&iacute;sticas, puedes tener una vista de los sitios de origen de las visitas',
'info_question_vignettes_referer_non' => 'No mostrar las capturas de los sitios de origen de las visitas',
'info_question_vignettes_referer_oui' => 'Mostrar las capturas de los sitios de origen de las visitas',
'info_question_visiteur_ajout_document_forum' => 'Si desea autorizar que los visitantes puedan depositar documentos (im&aacute;genes, sonidos...) en sus mensajes sobre los foros, indique aqu&iacute; debajo la lista de extensiones para los docuemnos autorizados en los foros (por ejemplo: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Si desea autorizar todos los tipos de documentos considerados como fiables por SPIP, coloque un asterisco. Para no autorizar ninguno, dejar en blanco.',
'info_qui_attribue_mot_cle' => 'Las palabras claves de este grupo pueden ser atribuidas por',
'info_racine_site' => 'Ra&iacute;z del sitio',
'info_recharger_page' => 'Por favor recargue esta p&aacute;gina dentro de un momento',
'info_recherche_auteur_a_affiner' => 'Hay demasiados resultados para "@cherche_auteur@", por favor restrinja los criterios.',
'info_recherche_auteur_ok' => 'Varios autores y/o autoras encontrado para "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'No hay resultados para &laquo;&nbsp;@cherche_auteur@&nbsp;&raquo;.',
'info_recommencer' => 'Vuelve a empezar',
'info_redacteur_1' => 'Redactor/a',
'info_redacteur_2' => 'Accediendo al espacio privado (<i>recomendado</i>)',
'info_redacteurs' => 'Redactores/as',
'info_redaction_en_cours' => 'En curso de redacci&oacute;n...',
'info_redirection' => 'Redirecci&oacute;n',
'info_referencer_doc_distant' => 'Referenciar un documento de Internet&nbsp;:',
'info_refuses' => 'Tus art&iacute;culos rechazados',
'info_reglage_ldap' => 'Opciones: <b>Ajustes de la importaci&oacute;n LDAP</b>',
'info_renvoi_article' => '<b>Redirecci&oacute;n.</b> Este art&iacute;culo reenv&iacute;a a la p&aacute;gina:',
'info_reserve_admin' => 'S&oacute;lo el equipo de administraci&oacute;n puede modificar esta direcci&oacute;n',
'info_restauration_sauvegarde' => 'Restauraci&oacute;n de la copia de respaldo @archive@',
'info_restauration_sauvegarde_insert' => 'Inserci&oacute;n de @archive@ en la base',
'info_restreindre_rubrique' => 'Limitar la gesti&oacute;n a la secci&oacute;n...',
'info_resultat_recherche' => 'Resultados de la b&uacute;squeda:',
'info_rubriques' => 'Secciones',
'info_rubriques_02' => 'secciones',
'info_rubriques_liees_mot' => 'Las secciones ligadas a esta palabra clave',
'info_rubriques_trouvees' => 'Secciones localizadas',
'info_rubriques_trouvees_dans_texte' => 'Secciones localizadas (en el texto)',
'info_sans_titre' => 'Sin t&iacute;tulo',
'info_sauvegarde' => 'Copia de respaldo',
'info_sauvegarde_articles' => 'Guardar los art&iacute;culos',
'info_sauvegarde_articles_sites_ref' => 'Guarar los art&iacute;culos de los sitios referenciados',
'info_sauvegarde_auteurs' => 'Crear un respaldo de los autores y autoras',
'info_sauvegarde_breves' => 'Guarar las breves',
'info_sauvegarde_documents' => 'Guardar los documentos',
'info_sauvegarde_echouee' => 'Si ha fallado al guardar (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Guardar los foros',
'info_sauvegarde_groupe_mots' => 'Guardar los grupos de palabras',
'info_sauvegarde_messages' => 'Guardar los mensajes',
'info_sauvegarde_mots_cles' => 'Guardar las palabras clave',
'info_sauvegarde_petitions' => 'Guardar las peticiones',
'info_sauvegarde_refers' => 'Guardar los "referers"',
'info_sauvegarde_reussi_01' => 'Copia de respaldo lograda.',
'info_sauvegarde_reussi_02' => 'El respaldo de la base est&aacute; en @archive@. Puedes',
'info_sauvegarde_reussi_03' => 'volver a la gesti&oacute;n',
'info_sauvegarde_reussi_04' => 'del sitio.',
'info_sauvegarde_rubrique_reussi' => 'Las tablas de la secci&oacute;n @titre@ se han guardado en @archive@. Puedes',
'info_sauvegarde_rubriques' => 'Guardar las secciones',
'info_sauvegarde_signatures' => 'Guardar las firmas de las peticiones',
'info_sauvegarde_sites_references' => 'Guardar los sitios referenciados',
'info_sauvegarde_type_documents' => 'Guardar los tipos de documentos',
'info_sauvegarde_visites' => 'Guardar las visitas',
'info_selection_chemin_acces' => 'Selecciona el camino de acceso en el anuario',
'info_selection_un_seul_mot_cle' => 'S&oacute;lo se puede seleccionar <b>una palabra</b> a la vez en este grupo',
'info_signatures' => 'firmas',
'info_site' => 'Sitio',
'info_site_2' => 'sitio:',
'info_site_min' => 'sitio',
'info_site_propose' => 'Sitio propuesto el',
'info_site_reference_2' => 'Sitio referenciado',
'info_site_syndique' => 'Este sitio est&aacute; sindicado...',
'info_site_valider' => 'Sitios a validar',
'info_site_web' => 'Sitio Web:',
'info_sites' => 'sitios',
'info_sites_lies_mot' => 'Los sitios referenciados ligados a esta palabra clave',
'info_sites_proxy' => 'Utilizar un proxy',
'info_sites_refuses' => 'Los sitios rechazados',
'info_sites_trouves' => 'Sitios hallados',
'info_sites_trouves_dans_texte' => 'Sitios encontrados (en el texto)',
'info_sous_titre' => 'Subt&iacute;tulo',
'info_statut_administrateur' => 'Administrador/a',
'info_statut_auteur' => 'Papel de este autor o autora:',
'info_statut_auteur_a_confirmer' => 'Inscripci&oacute;n por confirmar',
'info_statut_auteur_autre' => 'Otro papel:',
'info_statut_efface' => 'Borrado',
'info_statut_redacteur' => 'Redactor/a',
'info_statut_site_1' => 'Este sitio est&aacute;:',
'info_statut_site_2' => 'Publicado',
'info_statut_site_3' => 'Propuesto',
'info_statut_site_4' => 'A la papelera',
'info_statut_utilisateurs_1' => 'Estado por omisi&oacute;n de las personas importadas',
'info_statut_utilisateurs_2' => 'Elegir el estado atribuido a las personas presentes en el directorio LDAP cuando se conectan por primera vez. Posteriormente se podr&aacute; modificar el estado caso por caso.',
'info_suivi_activite' => 'Seguimiento de la actividad editorial',
'info_supprimer_mot' => 'Suprimir esta palabra',
'info_surtitre' => 'Antet&iacute;tulo',
'info_syndication_integrale_1' => 'Tu sitio propone archivos de sindicaci&oacute;n (ver &laquo;<a href="@url@">@titre@</a>&raquo;).',
'info_syndication_integrale_2' => '&iquest;Deseas transmitir &iacute;ntegramente los art&iacute;culos, o s&oacute;lo un resumen compuesto por unos cientos de caracteres?',
'info_table_prefix' => 'Puedes modificar el prefijo del nombre de las tablas de datos (es indispensable si se quiere instalar varios sitios en la misma base de datos). Este prefijo debe ser en letras min&uacute;sculas, no acentuadas, y sin espacios. ',
'info_taille_maximale_images' => 'SPIP comprobar&aacute; el tama&ntilde;o m&aacute;ximo de imagen que puede gestionar (en millones de pixels).<br /> Las im&aacute;genes mayores no se reducir&aacute;n.',
'info_taille_maximale_vignette' => 'Dimensiones m&aacute;ximas de los iconos generados :',
'info_terminer_installation' => 'Terminar la instalaci&oacute;n.',
'info_texte' => 'Texto',
'info_texte_explicatif' => 'Texto explicativo',
'info_texte_long' => '(El texto es largo y aparece en varias partes que se reunir&aacute;n despu&eacute;s de la validaci&oacute;n)',
'info_texte_message' => 'Texto del mensaje',
'info_texte_message_02' => 'Texto del mensaje',
'info_titre' => 'T&iacute;tulo',
'info_titre_mot_cle' => 'T&iacute;tulo de la palabra clave',
'info_total' => 'Total:',
'info_tous_articles_en_redaction' => 'Todos los art&iacute;culos en curso de redacci&oacute;n',
'info_tous_articles_presents' => 'Todos los art&iacute;culos publicados en esta secci&oacute;n',
'info_tous_articles_refuses' => 'Todos los art&iacute;culos rechazados',
'info_tous_les' => 'todos los:',
'info_tous_redacteurs' => 'Anuncios a todos',
'info_tout_site' => 'Todo el sitio',
'info_tout_site2' => 'El art&iacute;culo no ha sido traducido a este idioma.',
'info_tout_site3' => 'El art&iacute;culo ha sido traducido a este idioma, pero posteriormente modificaciones fueron aportadas al art&iacute;culo de referencia. La traducci&oacute;n debe ser actualizada.',
'info_tout_site4' => 'El art&iacute;culo ha sido traducido a este idioma, y la traducci&oacute;n est&aacute; al d&iacute;a. ',
'info_tout_site5' => 'Art&iacute;culo original',
'info_tout_site6' => '<b>Atenci&oacute;n:</b> s&oacute;lo se muestran los art&iacute;culos originales.
Las traducciones est&aacute;n asociadas al original, en un color que indica su estado:',
'info_travail_colaboratif' => 'Trabajo colectivo en los art&iacute;culos',
'info_un_article' => 'un art&iacute;culo,',
'info_un_mot' => 'Una sola palabra a la vez',
'info_un_site' => 'un sitio,',
'info_une_breve' => 'una breve,',
'info_une_rubrique' => 'una secci&oacute;n,',
'info_une_rubrique_02' => '1 secci&oacute;n',
'info_url' => 'URL:',
'info_url_site' => 'URL del sitio:',
'info_urlref' => 'Enlace hipertexto:',
'info_utilisation_spip' => 'Puedes comenzar a utilizar el sistema de publicaci&oacute;n asistida...',
'info_visites_par_mois' => 'Mostrar por mes :',
'info_visites_plus_populaires' => 'Mostrar las visitas de <b>los art&iacute;culos m&aacute;s populares</b> y de <b>los &uacute;ltimos art&iacute;culos publicados</b>',
'info_visiteur_1' => 'Visitante',
'info_visiteur_2' => 'del sitio p&uacute;blico',
'info_visiteurs' => 'Visitantes',
'info_visiteurs_02' => 'Visitantes del sitio p&uacute;blico',
'install_adresse_base_hebergeur' => 'Direcci&oacute;n de la base de datos asignada por el proveedor del alojamiento',
'install_base_ok' => 'La base @base@ ha sido reconocida',
'install_echec_annonce' => 'La instalaci&oacute;n probablemente va a fallar, o crear&aacute; un sitio que no funcione...',
'install_extension_mbstring' => 'SPIP no funciona con&nbsp;:',
'install_extension_php_obligatoire' => 'SPIP exige instalar la extensi&oacute;n php&nbsp;:',
'install_login_base_hebergeur' => 'Login de conexi&oacute;n asignada por el proveedor del alojamiento',
'install_nom_base_hebergeur' => 'Nombre de la base asignada por el proveedor&nbsp;:',
'install_pas_table' => 'La base no tiene tablas en este momento',
'install_pass_base_hebergeur' => 'Clave de paso asignada por el proveedor',
'install_php_version' => 'PHP versi&oacute;n @version@ insuficiente (m&iacute;nimo = @minimum@)',
'install_select_langue' => 'Selecciona un idioma y despu&eacute;s pulsa el bot&oacute;n &laquo;siguiente&raquo; para iniciar el proceso de instalaci&oacute;n.',
'install_select_type_db' => 'Indicar el tipo de base de datos:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL',
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Servidor de base de datos asignado por tu proveedor',
'install_table_prefix_hebergeur' => 'Prefijo de la tabla asignada por el proveedor&nbsp;:',
'install_tables_base' => 'Tablas de la base',
'install_types_db_connus' => 'SPIP sabe utilizar <b>MySQL</b> (el m&aacute;s extendido), <b>PostgreSQL</b> y <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'Atenci&oacute;n: varios plugins s&oacute;lo funcionan con MySQL',
'intem_redacteur' => 'redactor/a',
'intitule_licence' => 'Licencia',
'item_accepter_inscriptions' => 'Aceptar las inscripciones',
'item_activer_forum_administrateur' => 'Activar el foro del equipo de administraci&oacute;n.',
'item_activer_messages_avertissement' => 'Activar los mensajes de advertencia',
'item_administrateur_2' => 'administrador/a',
'item_afficher_calendrier' => 'Mostrar en el calendario',
'item_ajout_mots_cles' => 'Autorizar las palabres claves en los foros',
'item_autoriser_documents_joints' => 'Autorizar los documentos adjuntos a los art&iacute;culos',
'item_autoriser_documents_joints_rubriques' => 'Autorizar los documentos en las secciones',
'item_autoriser_selectionner_date_en_ligne' => 'Permitir la modificaci&oacute;n de la fecha de cada documento',
'item_autoriser_syndication_integrale' => 'Difundir &iacute;ntegramente los art&iacute;culos en los archivos de sindicaci&oacute;n',
'item_bloquer_liens_syndiques' => 'Bloquear los enlaces sindicados en validaci&oacute;n',
'item_breve_refusee' => 'Breve rechazada',
'item_breve_validee' => 'Breve validada',
'item_choix_administrateurs' => 'los administradores/as',
'item_choix_generation_miniature' => 'Generar autom&aacute;ticamente las miniaturas de las im&aacute;genes',
'item_choix_non_generation_miniature' => 'No generar miniaturas',
'item_choix_redacteurs' => 'los redactores/as',
'item_choix_visiteurs' => 'los y las visitantes del sitio',
'item_compresseur' => 'Activar la compresi&oacute;n',
'item_config_forums_prive_global' => 'Activar el foro de los redactores',
'item_config_forums_prive_objets' => 'Activar estos foros',
'item_creer_fichiers_authent' => 'Crear los archivos &laquo;.htpasswd&raquo;',
'item_desactiver_forum_administrateur' => 'Desactivar el foro de administraci&oacute;n',
'item_gerer_annuaire_site_web' => 'Gestionar un directorio de sitios Web',
'item_gerer_statistiques' => 'Gestionar las estad&iacute;sticas',
'item_limiter_recherche' => 'Limitar la b&uacute;squeda a este sitio',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Activar la mensajer&iacute;a y la agenda',
'item_mots_cles_association_articles' => 'a los art&iacute;culos',
'item_mots_cles_association_breves' => 'a las breves',
'item_mots_cles_association_rubriques' => 'a las secciones',
'item_mots_cles_association_sites' => 'a los sitios referenciados o sindicados',
'item_non' => 'No',
'item_non_accepter_inscriptions' => 'No aceptar inscripciones',
'item_non_activer_messages_avertissement' => 'Sin mensajes de advertencia',
'item_non_afficher_calendrier' => 'No mostrar en el calendario',
'item_non_ajout_mots_cles' => 'Impedir la utilizaci&oacute;n de las palabras clave en los foros',
'item_non_autoriser_documents_joints' => 'Impedir la inclusi&oacute;n de documentos en los art&iacute;culos',
'item_non_autoriser_documents_joints_rubriques' => 'Impedir la inclusi&oacute;n de documentos en las secciones',
'item_non_autoriser_selectionner_date_en_ligne' => 'La fecha de los documentos es la de subida al sitio web',
'item_non_autoriser_syndication_integrale' => 'S&oacute;lo difundir un resumen',
'item_non_bloquer_liens_syndiques' => 'No bloquear los enlaces de sindicaci&oacute;n',
'item_non_compresseur' => 'Desactivar la compresi&oacute;n',
'item_non_config_forums_prive_global' => 'Desactivar el foro de los redactores',
'item_non_config_forums_prive_objets' => 'Desactivar estos foros',
'item_non_creer_fichiers_authent' => 'No crear esos archivos',
'item_non_gerer_annuaire_site_web' => 'Desactivar el directorio de sitios Web',
'item_non_gerer_statistiques' => 'No gestionar las estad&iacute;sticas',
'item_non_limiter_recherche' => 'Buscar en el contenido de los sitios referenciados',
'item_non_messagerie_agenda' => 'Desactivar la mensajer&iacute;a y la agenda',
'item_non_publier_articles' => 'No publicar los art&iacute;culos antes de la fecha de publicaci&oacute;n indicada',
'item_non_utiliser_breves' => 'No utilizar las breves',
'item_non_utiliser_config_groupe_mots_cles' => 'No utilizar la configuraci&oacute;n precisa de los grupos de palabras clave',
'item_non_utiliser_moteur_recherche' => 'No utilizar el motor',
'item_non_utiliser_mots_cles' => 'No utilizar las palabras clave',
'item_non_utiliser_syndication' => 'No utilizar la sindicaci&oacute;n autom&aacute;tica',
'item_nouvel_auteur' => 'Nueva autora o autor',
'item_nouvelle_breve' => 'Nueva breve',
'item_nouvelle_rubrique' => 'Nueva secci&oacute;n',
'item_oui' => 'S&iacute;',
'item_publier_articles' => 'Publicar los art&iacute;culos sin tener en cuenta la fecha de publicaci&oacute;n',
'item_reponse_article' => 'Respuesta al art&iacute;culo',
'item_utiliser_breves' => 'Utilizar las breves',
'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuraci&oacute;n precisa de los grupos de palabras clave',
'item_utiliser_moteur_recherche' => 'Utilizar el motor de b&uacute;squeda',
'item_utiliser_mots_cles' => 'Utilizar las palabras clave',
'item_utiliser_syndication' => 'Utilizar la sindicaci&oacute;n autom&aacute;tica',
'item_visiteur' => 'visitante',

// J
'jour_non_connu_nc' => 'n.c.',

// L
'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
'lien_ajout_destinataire' => 'A&ntilde;adir este destinatario o destinataria',
'lien_ajouter_auteur' => 'A&ntilde;adir esta autor/a',
'lien_ajouter_participant' => 'A&ntilde;adir un/una participante',
'lien_email' => 'correo electr&oacute;nico',
'lien_forum_public' => 'Gestionar el foro de este art&iacute;culo',
'lien_mise_a_jour_syndication' => 'Actualizar ahora',
'lien_nom_site' => 'Nombre del sitio',
'lien_nouvelle_recuperation' => 'Intentar recuperar nuevamente los datos',
'lien_reponse_article' => 'Respuesta al art&iacute;culo',
'lien_reponse_breve' => 'Respuesta a la breve',
'lien_reponse_breve_2' => 'Respuesta a la breve',
'lien_reponse_rubrique' => 'Respuesta a la secci&oacute;n',
'lien_reponse_site_reference' => 'Respuesta al sitio referenciado',
'lien_retirer_auteur' => 'Retirar esta autor/a',
'lien_retrait_particpant' => 'Retirar este/esta participante',
'lien_site' => 'sitio',
'lien_supprimer_rubrique' => 'Suprimir esta secci&oacute;n',
'lien_tout_deplier' => 'Desplegar todo',
'lien_tout_replier' => 'Replegar todo',
'lien_tout_supprimer' => 'Suprimir todo',
'lien_trier_nom' => 'Ordenar por nombre',
'lien_trier_nombre_articles' => 'Ordenar por n&uacute;mero de art&iacute;culos',
'lien_trier_statut' => 'Ordenar por estado',
'lien_voir_en_ligne' => 'Ver en l&iacute;nea...',
'logo_article' => 'Logotipo del art&iacute;culo...',
'logo_auteur' => 'LOGO DEL AUTOR O AUTORA',
'logo_breve' => 'Logotipo de la breve...',
'logo_mot_cle' => 'Logotipo de la palabra clave...',
'logo_rubrique' => 'Logotipo de la secci&oacute;n...',
'logo_site' => 'Logotipo del sitio...',
'logo_standard_rubrique' => 'Logotipo est&aacute;ndar de las secciones...',
'logo_survol' => 'Logotipo paso del rat&oacute;n...',

// M
'menu_aide_installation_choix_base' => 'Elegir tu base',
'module_fichier_langue' => 'Archivo de idioma',
'module_raccourci' => 'Atajo',
'module_texte_affiche' => 'Texto mostrado',
'module_texte_explicatif' => 'Puedes insertar los atajos siguientes en los esqueletos de tu sitio p&uacute;blico. Ser&aacute;n traducidos autom&aacute;ticamente en los diferentes idiomas para los cuales existe un archivo de idioma.',
'module_texte_traduction' => 'El archivo de idioma &laquo;&nbsp;@module@&nbsp;&raquo; est&aacute; disponible en:',
'mois_non_connu' => 'desconocido',

// N
'nouvelle_version_spip' => 'La versi&oacute;n @version@ de SPIP est&aacute; disponible',

// O
'onglet_contenu' => 'Contenido',
'onglet_declarer_une_autre_base' => 'Declarar otra base',
'onglet_discuter' => 'Discutir',
'onglet_documents' => 'Documentos',
'onglet_interactivite' => 'Interactividad',
'onglet_proprietes' => 'Propriedades',
'onglet_repartition_actuelle' => 'actualmente',
'onglet_sous_rubriques' => 'Sub-secciones',

// P
'page_pas_proxy' => 'Esta p&aacute;gina no debe pasar por el proxy',
'pas_de_proxy_pour' => 'Si fuera el caso, indica los servidores o  dominios para los cuales este proxy no debe aplicarse. (por ejemplo: @exemple@)',
'plugin_charge_paquet' => 'Carga del paquete @name@',
'plugin_charger' => 'Descargar',
'plugin_erreur_charger' => 'error: no es posible cargar @zip@',
'plugin_erreur_droit1' => 'La carpeta <code>@dest@</code> no est&aacute; accesible en modo escritura.',
'plugin_erreur_droit2' => 'Tendr&aacute;s que verificar los derechos en esta carpeta (o crearla si es el caso), o instalar los archivos por FTP.',
'plugin_erreur_zip' => 'fallo de pclzip: error @status@',
'plugin_etat_developpement' => 'en desarrollo',
'plugin_etat_experimental' => 'experimental',
'plugin_etat_stable' => 'estable',
'plugin_etat_test' => 'en prueba',
'plugin_impossible_activer' => 'Imposible activar el plugin @plugin@',
'plugin_info_automatique1' => 'Si quieres autorizar la instalaci&oacute;n autom&aacute;tica de los plugins, tienes que:',
'plugin_info_automatique1_lib' => 'Si deseas autorizar la instalaci&oacute;n autom&aacute;tica de esta librer&iacute;a, consulta:',
'plugin_info_automatique2' => 'crear una carpeta <code>@rep@</code>&nbsp;;',
'plugin_info_automatique3' => 'verificar que el servidor tiene permiso para escribir en esa carpeta.',
'plugin_info_automatique_creer' => 'que hay que crear en la ra&iacute;z del sitio.',
'plugin_info_automatique_exemples' => 'ejemplos:',
'plugin_info_automatique_ftp' => 'Puedes instalar plugins, por FTP, en la carpeta <tt>@rep@</tt>',
'plugin_info_automatique_lib' => 'Ciertos plugins tambi&eacute;n requieren que se pueda descargar archivos a la carpeta <code>lib/</code>, que habr&aacute; que crear, si es el caso, en la ra&iacute;z del sitio.',
'plugin_info_automatique_liste' => 'Tus listas de plugins:',
'plugin_info_automatique_liste_officielle' => 'los plugins oficiales',
'plugin_info_automatique_liste_update' => 'Actualizar las listas',
'plugin_info_automatique_ou' => 'donde...',
'plugin_info_automatique_select' => 'Selecciona un plugin de aqu&iacute;: SPIP lo descargar&aacute; y lo instalar&aacute; en la carpeta <code>@rep@</code>; si el plugin ya existe, se actualizar&aacute;.',
'plugin_info_extension_1' => 'Las extensiones siguientes se cargan y se activan en la carpeta @extensions@.',
'plugin_info_extension_2' => 'Ellas no son desactivables.',
'plugin_info_telecharger' => 'se descargar&aacute; de @url@ y se instalar&aacute; en @rep@',
'plugin_librairies_installees' => 'Bibliotecas instaladas',
'plugin_necessite_lib' => 'Este plugin necesita la biblioteca @lib@',
'plugin_necessite_plugin' => 'Necesita el plugin @plugin@ con versi&oacute;n @version@ por lo menos.',
'plugin_necessite_spip' => 'Necesita como m&iacute;nimo un SPIP de versi&oacute;n @version@.',
'plugin_source' => 'fuente:&nbsp;',
'plugin_titre_automatique' => 'Instalaci&oacute;n autom&aacute;tica',
'plugin_titre_automatique_ajouter' => 'A&ntilde;adir plugins',
'plugin_titre_installation' => 'Instalaci&oacute;n del plugin @plugin@',
'plugin_zip_active' => 'Contin&uacute;a para activarlo',
'plugin_zip_adresse' => 'indica aqu&iacute; la direcci&oacute;n de un archivo zip de plugin a descargar, o tambi&eacute;n la direcci&oacute;n de una lista de plugins.',
'plugin_zip_adresse_champ' => 'Direcci&oacute;n del plugin o de la lista&nbsp;',
'plugin_zip_content' => 'Contiene los siguientes archivos (@taille@),<br />que se instalar&aacute;n en la carpeta <code>@rep@</code>',
'plugin_zip_installe_finie' => 'El archivo @zip@ se ha descomprimido e instalado.',
'plugin_zip_installe_rep_finie' => 'El archivo @zip@ se ha descomprimido y se ha instalado en la carpeta @rep@',
'plugin_zip_installer' => 'Ahora puedes instalarlo.',
'plugin_zip_telecharge' => 'Se ha descargado el archivo @zip@',
'plugins_actif_aucun' => 'Ning&uacute;n plugin activado.',
'plugins_actif_un' => 'Un plugin activado.',
'plugins_actifs' => '@count@ plugins activados.',
'plugins_actifs_liste' => 'Plugins activos',
'plugins_compte' => '@count@ plugins',
'plugins_disponible_un' => 'Un plugin disponible.',
'plugins_disponibles' => '@count@ plugins disponibles.',
'plugins_erreur' => 'Error en los plugins: @plugins@',
'plugins_liste' => 'Lista de plugins',
'plugins_liste_extensions' => 'Extensiones',
'plugins_recents' => 'Plugins recientes.',
'plugins_vue_hierarchie' => 'Jerarqu&iacute;a',
'plugins_vue_liste' => 'Lista',
'protocole_ldap' => 'Versi&oacute;n del protocolo:',

// R
'repertoire_plugins' => 'Carpeta:',

// S
'sans_heure' => 'sin hora',
'sauvegarde_fusionner' => 'Fusionar la base actual y el respaldo',
'sauvegarde_fusionner_depublier' => 'Despublicar los objetos fusionados',
'sauvegarde_url_origine' => 'Eventualemente, URL del sitio de origen:',
'statut_admin_restreint' => '(administrador restringido)',
'syndic_choix_moderation' => '&iquest;Qu&eacute; hacemos con los siguientes enlaces que vengan de este sitio?',
'syndic_choix_oublier' => '&iquest;Qu&eacute; hacemos con los enlaces que no figuren en el archivo de sindicaci&oacute;n?',
'syndic_choix_resume' => 'Algunos sitios difunden el texto completo de los art&iacute;culos. Cuando est&eacute; disponible, deseas sindicar:',
'syndic_lien_obsolete' => 'enlace obsoleto',
'syndic_option_miroir' => 'bloquearlos autom&aacute;ticamente',
'syndic_option_oubli' => 'borrarlos (tras @mois@&nbsp;meses)',
'syndic_option_resume_non' => 'el contenido completo de los art&iacute;culos (en formato HTML)',
'syndic_option_resume_oui' => 'un simple resumen (en formato texto)',
'syndic_options' => 'Opciones de sindicaci&oacute;n:',

// T
'taille_cache_image' => 'Las im&aacute;genes calculadas autom&aacute;ticamente por SPIP (miniaturas de documentos, t&iacute;tulos presentados en forma gr&aacute;fica, f&oacute;rmulas matem&aacute;ticas en formato TeX...) ocupan en el directorio @dir@ un total de @taille@.',
'taille_cache_infinie' => 'En este sitio no se limita el tama&ntilde;o de la carpeta de cache.',
'taille_cache_maxi' => 'SPIP intenta limitar el tama&ntilde;o de la carpeta de cache de este sitio a unos <b>@octets@</b> de datos.',
'taille_cache_octets' => 'El tama&ntilde;o de la cache es actualmente de @octets@.',
'taille_cache_vide' => 'La cache est&aacute; vac&iacute;a.',
'taille_repertoire_cache' => 'Tama&ntilde;o de la carpeta cache',
'text_article_propose_publication' => 'Art&iacute;culo propuesto para su publicaci&oacute;n.',
'text_article_propose_publication_forum' => 'Expresa tu opini&oacute;n mediante el foro adjunto al art&iacute;culo (en la parte inferior de la p&aacute;gina).',
'texte_acces_ldap_anonyme_1' => 'Algunos servidores LDAP no aceptan accesos an&oacute;nimos. En ese caso debes especificar un identificador de acceso inicial para poder luego buscar informaciones en el directorio. En la mayor&iacute;a de los casos los campos siguientes pueden estar vac&iacute;os.',
'texte_admin_effacer_01' => 'Este comando borra <i>TODO</i> el contenido de la base de datos, redactoras y administradores inclu&iacute;dos. Despu&eacute;s de ejecutarlo tendr&aacute;s que volver a instalar SPIP, creando una nueva base al igual que un primer acceso de administraci&oacute;n.',
'texte_admin_effacer_stats' => 'Esta orden borra todos los datos ligados con las estad&iacute;sticas de visitas al sitio, incluyendo la popularidad de los art&iacute;culos.',
'texte_admin_tech_01' => 'Esta opci&oacute;n permite respaldar el contenido de la base en un archivo que se guardar&aacute; en la carpeta @dossier@. No olvides recuperar adem&aacute;s la totalidad de la carpeta @img@, que contiene las im&aacute;genes y los documentos utilizadas en los art&iacute;culos y las secciones.',
'texte_admin_tech_02' => '&iexcl;ATENCI&Oacute;N! Esta copia de respaldo S&Oacute;LO PODR&Aacute; ser restaurada en un sitio que utiliza LA MISMA versi&oacute;n de SPIP. Por ning&uacute;n motivo se deber&aacute; &laquo;&nbsp;vaciar la base&nbsp;&raquo; imaginando volver a instalar el respaldo despu&eacute;s de una actualizaci&oacute;n. Consultar la <a href="@spipnet@">documentaci&oacute;n de SPIP</a>.',
'texte_admin_tech_03' => 'Puedes elegir de guardar el archivo comprimido, y as&iacute; acortar el tiempo de transferencia hacia tu ordenador o un servidor de respaldo, aparte de ganar espacio en el disco.',
'texte_admin_tech_04' => 'En caso de fusi&oacute;n con otra base, la copia de respaldo puede limitarse a la secci&oacute;n: ',
'texte_adresse_annuaire_1' => '(Si tu carpeta est&aacute; instalada en la misma m&aacute;quina que el sitio Web, se trata probablemente de "localhost".)',
'texte_ajout_auteur' => 'La siguiente autora o autor fue a&ntilde;adida al art&iacute;culo:',
'texte_annuaire_ldap_1' => 'Si tienes un acceso a un directorio(LDAP), puedes utilizarlo para importar autom&aacute;ticamente usuarios de SPIP.',
'texte_article_statut' => 'Este art&iacute;culo est&aacute;...',
'texte_article_virtuel' => 'Art&iacute;culo virtual',
'texte_article_virtuel_reference' => '<b>Art&iacute;culo virtual</b> O sea un art&iacute;culo referenciado en tu sitio pero redirigido hacia otra URL. Para suprimir la redirecci&oacute;n, borra la URL .',
'texte_aucun_resultat_auteur' => 'Ning&uacute;n resultado por "@cherche_auteur@"',
'texte_auteur_messagerie' => 'Este sitio puede indicarte permanentemente la lista de personas conectadas, lo que permite intercambiar mensajes en directo. Adem&aacute;s, puedes decidir de no aparecer en la lista (est&aacute;s &laquo;invisible&raquo; para las dem&aacute;s personas).',
'texte_auteur_messagerie_1' => 'En este sitio, SPIP permite intercambiar mensajes y realizar foros privados entre los participantes. Puedes participar o no en estos intercambios.',
'texte_auteurs' => 'LOS AUTORES Y AUTORAS',
'texte_breves' => 'Las breves son notas cortas y simples que permiten poner r&aacute;pidamente en l&iacute;nea informaciones concisas, por ejemplo para manejar rese&ntilde;as de prensa, un calendario de eventos...',
'texte_choix_base_1' => 'Elegir la base',
'texte_choix_base_2' => 'El servidor SQL contiene varias bases de datos.',
'texte_choix_base_3' => '<b>Selecciona</b> aqu&iacute; la que te fue atribu&iacute;da por tu proveedor de hospedaje:',
'texte_choix_table_prefix' => 'Prefijo de las tablas:',
'texte_commande_vider_tables_indexation' => 'Utilice esta comanda para vaciar las tablas de indexaci&oacute;n del motor de b&uacute;squeda integrado de SPIP. Permite ganar espacio en el disco.',
'texte_comment_lire_tableau' => 'El rango del art&iacute;culo, en la clasificaci&oacute;n por popularidad, est&aacute; indicado al margen; la popularidad del art&iacute;culo (una estimaci&oacute;n del n&uacute;mero de visitas cotidianas que recibir&aacute; si el ritmo actual de visitas se mantiene) y el n&uacute;mero de visitas recibidas desde el inicio se muestran en el men&uacute; que aparece cuando pasamos el cursor sobre el t&iacute;tulo.',
'texte_compacter_avertissement' => 'Atenci&oacute;n a no activar estas opciones durante el desarrollo de tu sitio: los elementos compactados pierden toda legibilidad.',
'texte_compacter_script_css' => 'SPIP puede compactar los scripts javascript y las hojas de estilo CSS, para almacenarlos en ficheros est&aacute;ticos; esto acelera la presentaci&oacute;n del sitio.',
'texte_compresse_ou_non' => '(comprimido o no)',
'texte_compresseur_page' => 'SPIP puede comprimir autom&aacute;ticamente cada p&aacute;gina que env&iacute;a a los
visitantes del sitio. Este ajuste permite optimizar la banda pasante (el
sitio es m&aacute;s r&aacute;pido en caso de una conexi&oacute;n de baja banda pasante), pero
requiere m&aacute;s potencia del servidor.',
'texte_compte_element' => '@count@ elemento',
'texte_compte_elements' => '@count@ elementos',
'texte_config_groupe_mots_cles' => '&iquest;Deseas activar la configuraci&oacute;n avanzada de las palabras clave, indicando, por ejemplo, que se puede seleccionar s&oacute;lo una palabra por grupo, que un grupo importante, ...?',
'texte_conflit_edition_correction' => 'Por favor revise aqu&iacute; debajo las diferencias entre las dos versiones del texto&nbsp;; tambi&eacute;n podr&aacute; copiar sus modificaciones, y luego volver a empezar.',
'texte_connexion_mysql' => 'Consulta la informaci&oacute;n facilitada por tu  hospedaje: ah&iacute; deber&iacute;as encontrar el nombre del servidor de base de datos que te ofrece y las claves e identificador para conectarte.',
'texte_contenu_article' => '(Contenido del art&iacute;culo en pocas palabras)',
'texte_contenu_articles' => 'Seg&uacute;n el dise&ntilde;o de tu sitio, puedes seleccionar aqu&iacute; los elementos a utilizar.',
'texte_crash_base' => 'Si la base tiene un problema, se puede intentar aqu&iacute; de repararla.',
'texte_creer_rubrique' => 'Antes de poder escribir art&iacute;culos,<br /> debes crear una secci&oacute;n.',
'texte_date_creation_article' => 'FECHA DE CREACI&Oacute;N DEL ART&Iacute;CULO:',
'texte_date_publication_anterieure' => 'Fecha de redacci&oacute;n anterior:',
'texte_date_publication_anterieure_nonaffichee' => 'No mostrar fecha de redacci&oacute;n anterior.',
'texte_date_publication_article' => 'Fecha de publicaci&oacute;n en l&iacute;nea:',
'texte_descriptif_petition' => 'Descripci&oacute;n de la petici&oacute;n',
'texte_descriptif_rapide' => 'Descripci&oacute;n r&aacute;pida',
'texte_documents_joints' => 'Puedes autorizar el a&ntilde;adir documentos (archivos de ofim&aacute;tica, im&aacute;genes,
 multimedia, etc.) a los art&iacute;culos y/o las secciones. Despu&eacute;s, estos archivos
 pueden referenciarse en el art&iacute;culo,
 o mostrarse por separado.<p>',
'texte_documents_joints_2' => 'Este ajuste no impide la inserci&oacute;n de im&aacute;genes directamente en los art&iacute;culos.',
'texte_effacer_base' => 'Borrar la base de datos SPIP',
'texte_effacer_donnees_indexation' => 'Borrar los datos de indexaci&oacute;n',
'texte_effacer_statistiques' => 'Borrar las estad&iacute;sticas',
'texte_en_cours_validation' => 'Los art&iacute;culos y notas breves mostradas m&aacute;s adelante est&aacute;n propuestas para su publicaci&oacute;n.',
'texte_en_cours_validation_forum' => 'No dudes en dar tu opini&oacute;n mediante los foros adjuntos.',
'texte_enrichir_mise_a_jour' => 'Puedes enriquecer el formato de tu texto utilizando "atajos tipogr&aacute;ficos"',
'texte_fichier_authent' => '<b>&iquest;Debe SPIP crear los archivos especiales <tt>.htpasswd</tt>
 y <tt>.htpasswd-admin</tt> en la carpeta @dossier@?</b><p>
Estos archivos pueden servir para restringir el acceso a las autoras y administradores en otros lugares de tu sitio (programa externo de estad&iacute;sticas, por ejemplo).<p>
Si no le ves utilidad, puedes dejar esta opci&oacute;n con su valor por omisi&oacute;n (no crear los archivos).</p>',
'texte_informations_personnelles_1' => 'El sistema va a crear ahora un acceso personalizado al sitio.',
'texte_informations_personnelles_2' => '(Nota: si se trata de una reinstalaci&oacute;n, y tu acceso todav&iacute;a funciona, puedes ',
'texte_introductif_article' => '(Introducci&oacute;n del art&iacute;culo.)',
'texte_jeu_caractere' => 'Se aconseja emplear para el sitio el alfabeto universal <tt>utf-8</tt>): permite visualizar textos en todos los idiomas, y ya no plantea problemas de compatibilidad con navegadores modernos.',
'texte_jeu_caractere_2' => 'Cuidado: este parametro no provoca la conversi&oacute;n de textos ya ingresados en el sitio. ',
'texte_jeu_caractere_3' => 'Tu sitio est&aacute; actualmente instalado con el juego de caracteres:',
'texte_jeu_caractere_4' => 'Si no corresponde a la realidad de tus datos (por ejemplo, despu&eacute;s de una restauraci&oacute;n de base de datos), o si <em>empiezas este sitio</em> y deseas hacerlo con otro juego de caracteres, ind&iacute;calo aqu&iacute;:',
'texte_jeu_caractere_conversion' => 'Nota: puedes decidir de convertir una vez por todas el conjunto de los textos de tu sitio (art&iacute;culos, breves, foros, etc.) haciael alfabeto <tt>utf-8</tt>, visitando <a href="@url@">la p&aacute;gina de conversi&oacute;n hacia el l\'utf-8</a>.',
'texte_lien_hypertexte' => '(Si tu mensaje se refiere a un art&iacute;culo publicado en la Web, o a una p&aacute;gina que contiene m&aacute;s informaciones, indica a continuaci&oacute;n el t&iacute;tulo de la p&aacute;gina y su direcci&oacute;n URL.)',
'texte_liens_sites_syndiques' => 'Los enlaces salidos de los sitios sindicados pueden
 ser bloqueados a priori&nbsp;; el ajuste indicado
 a continuaci&oacute;n se refiere al ajuste
 predeterminado de los sitios sindicados despu&eacute;s
 de su creaci&oacute;n. De todos modos, posteriormente
 se puede desbloquear cada enlace individualmente, o
 escoger, sitio a sitio, el bloqueo de los
 enlaces que vienen de tal o cual sitio.',
'texte_login_ldap_1' => '(Dejar en blanco para un acceso an&oacute;nimo, o indicar la ruta completa, por ejemplo "<tt>uid=perez, ou=users, dc=mi-dominio, dc=com</tt>".)',
'texte_login_precaution' => '&iexcl;Atenci&oacute;n! Este es el nombre de usuario con el cual est&aacute;s conectado actualmente.
Utiliza este formulario con precauci&oacute;n...',
'texte_message_edit' => 'Atenci&oacute;n: este mensaje puede ser modificado por todos los administradores del sitio, y es visible por todos los redactores. Utilizar los anuncios solamente para exponer acontecimientos importantes de la vida del sitio.',
'texte_messagerie_agenda' => 'Una mensajer&iacute;a permite a los redactores del sitio comunicarse entre ellos directamente en el espacio privado. Esta mensajer&iacute;a est&aacute; asociada a una agenda.',
'texte_messages_publics' => 'Mensajes p&uacute;blicos del art&iacute;culo:',
'texte_mise_a_niveau_base_1' => 'Acabas de actualizar los archivos de SPIP.
 Ahora se debe actualizar la base de datos del sitio.',
'texte_modifier_article' => 'Modificar el art&iacute;culo:',
'texte_moteur_recherche_active' => '<b>El motor de b&uacute;squeda est&aacute; activado.</b> Utiliza este comando si deseas proceder a una reindexaci&oacute;n r&aacute;pida (despu&eacute;s de la restauraci&oacute;n de una copia de respaldo, por ejemplo). Nota que los documentos modificados de modo normal (mediante la interfaz SPIP) se vuelven a indexar autom&aacute;ticamente: esta orden s&oacute;lo es &uacute;til excepcionalmente.',
'texte_moteur_recherche_non_active' => 'El motor de b&uacute;squeda no est&aacute; activado.',
'texte_mots_cles' => 'Las palabras clave permiten crear enlaces tem&aacute;ticos entre los art&iacute;culos, independientemente de su emplazamiento dentro de las secciones. De este modo, puedes enriquecer la navegaci&oacute;n de tu sitio, o incluso utilizar estas propiedades para personalizar la presentaci&oacute;n de los art&iacute;culos dentro de tus esqueletos.',
'texte_mots_cles_dans_forum' => '&iquest;Quieres permitir el uso de las palabras clave, que los y las visitantes puedan seleccionar en los foros del sitio p&uacute;blico? (Atenci&oacute;n: esta opci&oacute;n es relativamente compleja de usar correctamente.)',
'texte_multilinguisme' => 'Si deseas manejar art&iacute;culos en varios idiomas, con una navegaci&oacute;n compleja, puedes agregar un men&uacute; de selecci&oacute;n de lengua para los art&iacute;culos y/o para las secciones en funci&oacute;n de la organizaci&oacute;n de tu sitio.',
'texte_multilinguisme_trad' => 'Tambi&eacute;n puedes activar un sistema de enlaces entre las diferentes traducciones de un art&iacute;culo. ',
'texte_non_compresse' => '<i>no comprimido</i> (tu servidor no soporta esta funcionalidad)',
'texte_non_fonction_referencement' => 'Puedes preferir no usar esta funci&oacute;n autom&aacute;tica, e indicar tu mismo los elementos concernientes a este sitio...',
'texte_nouveau_message' => 'Nuevo mensaje',
'texte_nouveau_mot' => 'Nueva palabra',
'texte_nouvelle_version_spip_1' => 'Has instalado una versi&oacute;n nueva de SPIP.',
'texte_nouvelle_version_spip_2' => 'Esta nueva versi&oacute;n necesita una actualizaci&oacute;n m&aacute;s completa que de costumbre. Si eres webmaster del sitio, borra el archivo @connect@ y retoma la instalaci&oacute;n con el fin de actualizar los par&aacute;metros de conexi&oacute;n a la base de datos.<p> (NB.: si has olvidado los par&aacute;metros de conexi&oacute;n, echale una mirada al archivo  @connect@ antes de suprimirlo...)</p>',
'texte_operation_echec' => 'Regresa a la p&aacute;gina anterior, selecciona otra base o crea una nueva. Verifica las informaciones facilitadas por tu proveedor de hospedaje.',
'texte_plus_trois_car' => 'm&aacute;s de 3 caracteres',
'texte_plusieurs_articles' => 'Se han encontrado varios autores o autoras para "@cherche_auteur@":',
'texte_port_annuaire' => '(En general, es adecuado el valor predeterminado.)',
'texte_presente_plugin' => 'Esta p&aacute;gina lista los plugins disponibles en el sitio. Puedes activar los plugin necesarios seleccionando la casilla correspondiente. ',
'texte_proposer_publication' => 'Cuando tu art&iacute;culo est&eacute; terminado, <br /> puedes proponer su publicaci&oacute;n.',
'texte_proxy' => 'En algunos casos (intranet, redes protegidas...), los sitios distantes (documentaci&oacute;n de SPIP, sitios sindicados, etc.) no son accesibles m&aacute;s que atrav&eacute;s de un <i>proxy HTTP</i>. En ese caso, indique a continuaci&oacute;n su direcci&oacute;n, bajo la forma <tt><html>http://proxy:8080</html></tt>. En general, se dejar&aacute; esta casilla vac&iacute;a.',
'texte_publication_articles_post_dates' => '&iquest;Qu&eacute; comportamiento debe adoptar SPIP frente a los art&iacute;culos cuya fecha de publicaci&oacute;n ha sido fijada con un plazo futuro?',
'texte_rappel_selection_champs' => '[Selecciona correctamente este campo.]',
'texte_recalcul_page' => 'Si deseas recalcular una sola p&aacute;gina utiliza el bot&oacute;n "Recalcular" en el espacio p&uacute;blico.',
'texte_recapitiule_liste_documents' => 'Esta p&aacute;gina recapitula la lista de documentos que has insertado en las secciones. Para modificar las informaciones de cada documento, utiliza el enlace de su secci&oacute;n.',
'texte_recuperer_base' => 'Reparar la base de datos',
'texte_reference_mais_redirige' => 'Art&iacute;culo referenciado en tu sitio y redirigido hacia otra URL.',
'texte_referencement_automatique' => '<b>Referenciar autom&aacute;ticamente un sitio</b><br />Se puede referenciar r&aacute;pidamente un sitio Web indicando aqu&iacute; la direcci&oacute;n URL deseada, o la direcci&oacute;n de su archivo de sindicaci&oacute;n. SPIP recuperar&aacute; autom&aacute;ticamente las informaciones correspondientes (t&iacute;tulo, descripci&oacute;n...).',
'texte_referencement_automatique_verifier' => 'Deber&iacute;as verificar la informaci&oacute;n facilitada por <tt>@url@</tt> antes de guardar.',
'texte_requetes_echouent' => '<b>Cuando algunas peticiones SQL fallan sistem&aacute;ticamente y sin raz&oacute;n aparente, es posible que sea debido a la base de datos en s&iacute;.</b><p>
Tu servidor SQL es capaz de reparar sus tablas cuando fueron da&ntilde;adas por accidente.  Puedes intentar aqu&iacute; esta reparaci&oacute;n: si falla, conserva una copia del resultado, que posiblemente contenga indicios de lo que no funciona...</p><p>
Si el problema persiste, contacta a tu hospedaje.</p>',
'texte_restaurer_base' => 'Restaurar el contenido de una copia de respaldo',
'texte_restaurer_sauvegarde' => 'Esta opci&oacute;n te permite restaurar una copia de respaldo de la base efectuada anteriormente. A tal efecto, se debe haber puesto el archivo que contiene la copia de respaldo en la carpeta  @dossier@.
Prudencia con esta funcionalidad: <b>las modificaciones o p&eacute;rdidas eventuales son irreversibles.</b>',
'texte_sauvegarde' => 'Crear una copia de respaldo de la base',
'texte_sauvegarde_base' => 'Crear una copia de respaldo de la base',
'texte_sauvegarde_compressee' => 'La copia de respaldo ser&aacute; guardada en un archivo no comprimido @fichier@.',
'texte_selection_langue_principale' => 'A continuaci&oacute;n puedes seleccionar el &laquo;idioma principal&raquo; del sitio. Esta selecci&oacute;n no obliga - &iexcl;afortunadamente! - a escribir los art&iacute;culos en el idioma elegido, pero permite determinar:
<ul><li> el formato predeterminado de las fechas en el sitio p&uacute;blico;</li>
<li> la naturaleza del motor tipogr&aacute;fico que SPIP debe utilizar para reproducir los textos;</li>
<li> el idioma utilizado en los formularios del sitio p&uacute;blico;</li>
<li> el idioma predeterminado para el espacio privado.</li></ul>',
'texte_signification' => 'Las barras oscuras representan las entradas acumuladas (total de las subsecciones), las barras claras el n&uacute;mero de visitas de cada secci&oacute;n.',
'texte_sous_titre' => 'Subt&iacute;tulo',
'texte_statistiques_visites' => '(Barras oscuras: domingo / curva oscura: evoluci&oacute;n del promedio)',
'texte_statut_attente_validation' => 'En espera de validaci&oacute;n',
'texte_statut_publies' => 'Publicados',
'texte_statut_refuses' => 'Rechazados',
'texte_suppression_fichiers' => 'Utiliza esta operaci&oacute;n para suprimir todos los archivos presentes en la cach&eacute; de SPIP. Esto permite, por ejemplo, forzar la actualizaci&oacute;n de todas las p&aacute;ginas si se hicieron importantes modificaciones gr&aacute;ficas o de estructura del sitio.',
'texte_sur_titre' => 'Antet&iacute;tulo',
'texte_syndication' => 'Es posible recuperar autom&aacute;ticamente, cuando un sitio Web lo permite,
 la lista de novedades. Para ello, debes activar la sindicaci&oacute;n.
<blockquote><i>Algunos proveedores de hospedaje desactivan esta funcionalidad&nbsp;;
 en ese caso, no podr&aacute;s utilizar la sindicaci&oacute;n de contenido desde tu sitio.</i></blockquote>',
'texte_table_ok' => ': esta tabla est&aacute; bien.',
'texte_tables_indexation_vides' => 'Las tablas del motor de indexaci&oacute;n est&aacute;n vac&iacute;as.',
'texte_tentative_recuperation' => 'Tentativa de reparaci&oacute;n.',
'texte_tenter_reparation' => 'Intentar la reparaci&oacute;n de la base de datos.',
'texte_test_proxy' => 'Para ensayar este "proxy" indique aqu&iacute; la URL del sitio.',
'texte_titre_02' => 'T&iacute;tulo',
'texte_titre_obligatoire' => '<b>T&iacute;tulo</b> [Obligatorio]',
'texte_travail_article' => '@nom_auteur_modif@ ha trabajado sobre este art&iacute;culo hace @date_diff@ minutos.',
'texte_travail_collaboratif' => 'Es frecuente que varios redactores y redactoras trabajen sobre el mismo art&iacute;culo, el sistema puede mostrar los art&iacute;culos recientemente &laquo;abiertos&raquo; para  evitar las modificaciones simult&aacute;neas.
 Esta opci&oacute;n est&aacute; desactivada por omisi&oacute;n para evitar mostrar mensajes de advertencia intempestivos.',
'texte_trop_resultats_auteurs' => 'Demasiados resultados para la b&uacute;squeda de "@cherche_auteur@". Precise los criterios.',
'texte_type_urls' => 'Abajo puedes elegir el modo de calcular la direcci&oacute;n de las p&aacute;ginas.',
'texte_type_urls_attention' => 'Atenci&oacute;n, este ajuste s&oacute;lo funcionar&aacute; si el fichero @htaccess@ est&aacute; correctamente instalado en la ra&iacute;z del sitio web.',
'texte_unpack' => 'Descarga de la &uacute;ltima versi&oacute;n',
'texte_utilisation_moteur_syndiques' => 'Cuando utilizas el motor de b&uacute;squeda integrado
    en SPIP, puedes efectuar las b&uacute;squedas sobre los sitios y
    los art&iacute;culos sindicados de dos maneras 
    diferentes. <br />- La m&aacute;s
    simple consiste en buscar &uacute;nicamente en los
t&iacute;tulos y las descripciones de los art&iacute;culos. <br />- Un segundo m&eacute;todo, mucho m&aacute;s potente, permite a SPIP buscar tambi&eacute;n en el texto de los sitios referenciados. Si referencias un sitio, SPIP efectuar&aacute; entonces la b&uacute;squeda dentro del contenido de &eacute;ste.',
'texte_utilisation_moteur_syndiques_2' => 'Este m&eacute;todo obliga a SPIP a visitar regularmente los sitios referenciados, lo que provoca una ligera disminuci&oacute;n de velocidad de tu propio sitio.',
'texte_vide' => 'vac&iacute;o',
'texte_vider_cache' => 'Vaciar la cach&eacute;',
'titre_admin_effacer' => 'Mantenimiento t&eacute;cnico',
'titre_admin_tech' => 'Mantenimiento t&eacute;cnico',
'titre_admin_vider' => 'Mantenimiento t&eacute;cnico',
'titre_articles_syndiques' => 'Art&iacute;culos sindicados de este sitio',
'titre_breves' => 'Las breves',
'titre_cadre_afficher_article' => 'Mostrar los art&iacute;culos',
'titre_cadre_afficher_traductions' => 'Mostrar el estado de las traducciones para los idiomas siguientes:',
'titre_cadre_ajouter_auteur' => 'A&ntilde;adir un autor',
'titre_cadre_forum_administrateur' => 'Foro administradores',
'titre_cadre_forum_interne' => 'Foro interno',
'titre_cadre_interieur_rubrique' => 'Al interior de la secci&oacute;n',
'titre_cadre_numero_auteur' => 'AUTOR O AUTORA N&Uacute;MERO',
'titre_cadre_signature_obligatoire' => '<b>Firma</b> [Obligatoria]<br />',
'titre_compacter_script_css' => 'Compresi&oacute;n de los scripts y CSS',
'titre_compresser_flux_http' => 'Compresi&oacute;n del flujo HTTP',
'titre_config_contenu_notifications' => 'Notificaciones',
'titre_config_contenu_prive' => 'En el espacio privado',
'titre_config_contenu_public' => 'En el sitio p&uacute;blico',
'titre_config_fonctions' => 'Configuraci&oacute;n del sitio',
'titre_config_forums_prive' => 'Foros del espacio privado',
'titre_config_groupe_mots_cles' => 'Configuraci&oacute;n de los grupos de palabras clave',
'titre_configuration' => 'Configuraci&oacute;n del sitio',
'titre_conflit_edition' => 'Conflicto durante la edici&oacute;n',
'titre_connexion_ldap' => 'Opciones: <b>Tu conexi&oacute;n LDAP</b>',
'titre_dernier_article_syndique' => 'Ultimos art&iacute;culos sindicados',
'titre_documents_joints' => 'Documentos adjuntos',
'titre_evolution_visite' => 'Evoluci&oacute;n de las visitas',
'titre_forum_suivi' => 'Gesti&oacute;n de los foros',
'titre_gauche_mots_edit' => 'Palabra',
'titre_groupe_mots' => 'Grupo de palabras',
'titre_langue_article' => 'IDIOMA DEL ART&Iacute;CULO',
'titre_langue_breve' => 'IDIOMA DE LA BREVE',
'titre_langue_rubrique' => 'IDIOMA DE LA SECCI&Oacute;N',
'titre_langue_trad_article' => 'IDIOMA Y TRADUCCIONES DEL ART&Iacute;CULO',
'titre_les_articles' => 'Los art&iacute;culos',
'titre_messagerie_agenda' => 'Mensajer&iacute;a y agenda',
'titre_mots_cles_dans_forum' => 'Palabras clave en los foros del sitio p&uacute;blico',
'titre_mots_tous' => 'Las palabras clave',
'titre_naviguer_dans_le_site' => 'Navegar por el sitio...',
'titre_nouveau_groupe' => 'Nuevo grupo',
'titre_nouvelle_breve' => 'Nueva breve',
'titre_nouvelle_rubrique' => 'Nueva secci&oacute;n',
'titre_numero_rubrique' => 'SECCI&Oacute;N N&Uacute;MERO:',
'titre_page_admin_effacer' => 'Mantenimiento t&eacute;cnico: borrar la base',
'titre_page_articles_edit' => 'Modificar: @titre@',
'titre_page_articles_page' => 'Los art&iacute;culos',
'titre_page_articles_tous' => 'Todo el sitio',
'titre_page_auteurs' => 'Visitantes',
'titre_page_breves' => 'Breves',
'titre_page_breves_edit' => 'Modificar la nota breve: &laquo; @titre@ &raquo;',
'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Configuraci&oacute;n del sitio',
'titre_page_config_fonctions' => 'Configuraci&oacute;n del sitio',
'titre_page_configuration' => 'Configuraci&oacute;n del sitio',
'titre_page_controle_petition' => 'Seguimiento de las peticiones',
'titre_page_delete_all' => 'Supresi&oacute;n total e irreversible',
'titre_page_documents_liste' => 'Los documentos de las secciones',
'titre_page_forum' => 'Foro de los administradores',
'titre_page_forum_envoi' => 'Enviar un mensaje',
'titre_page_forum_suivi' => 'Seguimiento de los foros',
'titre_page_index' => 'Tu espacio privado',
'titre_page_message_edit' => 'Redactar un mensaje',
'titre_page_messagerie' => 'Tu mensajer&iacute;a',
'titre_page_mots_tous' => 'Palabras clave',
'titre_page_recherche' => 'Resultados de la b&uacute;squeda @recherche@',
'titre_page_sites_tous' => 'Los sitios referenciados',
'titre_page_statistiques' => 'Estad&iacute;sticas por secci&oacute;n',
'titre_page_statistiques_messages_forum' => 'Mensajes del foro',
'titre_page_statistiques_referers' => 'Estad&iacute;sticas (enlaces entrantes)',
'titre_page_statistiques_signatures_jour' => 'N&uacute;mero de firmas por d&iacute;a',
'titre_page_statistiques_signatures_mois' => 'N&uacute;mero de firmas por mes',
'titre_page_statistiques_visites' => 'Estad&iacute;sticas de las visitas',
'titre_page_upgrade' => 'Actualizaci&oacute;n de SPIP',
'titre_publication_articles_post_dates' => 'Publicaci&oacute;n de los art&iacute;culos con fecha posterior',
'titre_referencement_sites' => 'Agregar sitios y sindicar',
'titre_referencer_site' => 'Agregar un sitio:',
'titre_rendez_vous' => 'CITAS:',
'titre_reparation' => 'Reparaci&oacute;n',
'titre_site_numero' => 'Sitio',
'titre_sites_proposes' => 'Los sitios propuestos',
'titre_sites_references_rubrique' => 'Los sitios referenciados en esta secci&oacute;n',
'titre_sites_syndiques' => 'Los sitios sindicados',
'titre_sites_tous' => 'Los sitios referenciados',
'titre_suivi_petition' => 'Gesti&oacute;n de las peticiones',
'titre_syndication' => 'Sindicaci&oacute;n de sitios',
'titre_type_urls' => 'Tipo de direcciones URL',
'tls_ldap' => 'Transport Layer Security:',
'tout_dossier_upload' => 'Toda la carpeta @upload@',
'trad_article_inexistant' => 'No hay ning&uacute;n art&iacute;culo con ese n&uacute;mero.',
'trad_article_traduction' => 'Todas las versiones de este art&iacute;culo:',
'trad_deja_traduit' => 'Error: imposible de vincular este art&iacute;culo con el numero solicitado.',
'trad_delier' => 'Ya no ligar este art&iacute;culo a sus traducciones ',
'trad_lier' => 'Este art&iacute;culo es una traducci&oacute;n del art&iacute;culo n&uacute;mero:',
'trad_new' => 'Escribir una nueva traducci&oacute;n de este art&iacute;culo',

// U
'upload_fichier_zip' => 'Archivo ZIP',
'upload_fichier_zip_texte' => 'El archivo que te propones instalar es un archivo Zip.',
'upload_fichier_zip_texte2' => 'Este archivo puede ser:',
'upload_info_mode_document' => 'Dejar esta imagen en el portafolios',
'upload_info_mode_image' => 'Retirar esta imagen del portafolios',
'upload_limit' => 'Este archivo es demasiado grande para el servidor; el tama&ntilde;o m&aacute;ximo autorizado en <i>upload</i> es de @max@.',
'upload_zip_conserver' => 'Conservar el archivo tras la extracci&oacute;n',
'upload_zip_decompacter' => 'descomprimido y cada elemento que contiene instalado en el sitio. Los archivos que se van a instalar en el sitio son:',
'upload_zip_telquel' => 'instalado tal cual, como archivo Zip comprimido;',
'upload_zip_titrer' => 'Titular como el nombre de los archivos',
'utf8_convert_attendez' => 'Espera unos instantes y vuelve a cargar esta p&aacute;gina.',
'utf8_convert_avertissement' => 'Te aprontas a convertir el contenido de tu base de datos (art&iacute;culos, breves, etc) del juego de caracteres <b>@orig@</b> hacia el juego de caracteres <b>@charset@</b>.',
'utf8_convert_backup' => 'No te olvides de hacer primero un respaldo completo de tu sitio Tambi&eacute;n conviene verificar que tus esqueletos y archivos de idioma son compatibles @charset@.',
'utf8_convert_erreur_deja' => 'Tu sitio ya est&aacute; en @charset@, in&uacute;til convertirlo...',
'utf8_convert_erreur_orig' => 'Error: el juego de caracteres no est&aacute; soportado.',
'utf8_convert_termine' => '&iexcl;Se termin&oacute;!',
'utf8_convert_timeout' => '<b>Importante:</b> en caso de <i>timeout</i> del servidor, vuelve a cargar la p&aacute;gina hasta que indique &laquo;terminado&raquo;.',
'utf8_convert_verifier' => 'Ahora debes ir a vaciar la cache y verificar que todo funciona bien en las p&aacute;ginas p&uacute;blicas del sitio. En caso de graves problemas, un respaldo de los datos fue realizado (al formato SQL) en la carpeta @rep@.',
'utf8_convertir_votre_site' => 'Convertir tu sitio en utf-8',

// V
'version' => 'Versi&oacute;n:',
'version_deplace_rubrique' => 'Desplazado de <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> a <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Versi&oacute;n inicial'
);

?>
